# coding: utf8
from __future__ import unicode_literals
VERBS = set("""
 'γγίζω άγομαι άγχομαι άγω άδω άπτομαι άπωσον άρχομαι άρχω άφτω έγκειται έκιοσε
 έπομαι έρπω έρχομαι έστω έχω ήγγικεν ήθελε ίπταμαι ίσταμαι αίρομαι αίρω
 αβαντάρω αβαντζάρω αβαντσάρω αβαράρω αβασκαίνω αβγατίζω αβγαταίνω αβγοκόβω
 αβδελλώνω αβλεπτώ αβροδιαιτώμαι αγάλλομαι αγαθεύω αγαθολογώ αγαθοφέρνω
 αγαλλιώ αγανακτώ αγαναχτώ αγανοϋφαίνω αγαντάρω αγαπίζω αγαπιέμαι αγαπώ αγγέλλω
 αγγίζω αγγαρεύω αγγελιάζομαι αγγελοβλέπω αγγελοθωρώ αγγελοκρούομαι
 αγγλογλωττώ αγγλοποιώ αγγλοφέρνω αγγριφίζω αγιάζομαι αγιάζω αγιογραφώ
 αγιοποιώ αγκαζάρω αγκαθώνω αγκαλιάζομαι αγκαλιάζω αγκειάζω αγκιστρώνομαι
 αγκομαχώ αγκουσεύω αγκυλώνομαι αγκυλώνω αγκυροβολώ αγκωνιάζω αγλαΐζω αγλακώ
 αγναντεύω αγνοούμαι αγνοώ αγνωμονώ αγοράζομαι αγοράζω αγορεύω αγουροξυπνώ
 αγρεύω αγριεύομαι αγριεύω αγρικώ αγριοκοιτάζομαι αγριοκοιτάζω αγριοκοιτάω
 αγριοκοιτώ αγριομιλάω αγριομιλώ αγριώνομαι αγριώνω αγρυπνώ αγυρντίζω αγχώνομαι
 αγωγιάζω αγωνίζομαι αγωνιώ αδειάζω αδελφώνω αδερφώνω αδημονώ αδιαβροχοποιώ
 αδιαφορώ αδικοπραγώ αδικούμαι αδικώ αδολεσχώ αδράχνω αδρανοποιούμαι αδρανοποιώ
 αδροπληρώνω αδυνατίζω αδυνατώ αερίζομαι αερίζω αεριοποιούμαι αεριοποιώ
 αερολογώ αηδιάζω αηδονολαλώ αθανατίζω αθεΐζω αθετώ αθλοθετώ αθλούμαι αθροίζω
 αθωώνω αιδούμαι αιθεροβατώ αιθριάζω αιματοβάφομαι αιματοκυλίζω αιματοκυλώ
 αιμολύω αιμομικτώ αιμορραγώ αιμορροώ αινώ αισθάνομαι αισθηματολογώ αισθητοποιώ
 αισχροκερδώ αισχρολογώ αισχύνομαι αιτιάζομαι αιτιάζω αιτιολογώ αιτιώμαι
 αιτώ αιφνιδιάζομαι αιφνιδιάζω αιχμαλωτίζομαι αιχμαλωτίζω αιωρίζω αιωρούμαι
 ακαματεύω ακαρτερώ ακεραιώνω ακινητοποιούμαι ακινητοποιώ ακινητώ ακκίζομαι
 ακολασταίνω ακολουθώ ακομπανιάρω ακονίζομαι ακονίζω ακοντίζω ακοστάρω ακουμπάω
 ακούγομαι ακούγω ακούω ακριβαίνω ακριβοεξετάζω ακριβολογώ ακριβοπληρώνω
 ακροάζομαι ακροβατώ ακροβολίζομαι ακροπατώ ακροώμαι ακρωτηριάζω ακτινοβολώ
 ακτινοσκοπώ ακυριολεκτώ ακυρολεκτώ ακυρώνομαι ακυρώνω αλέθω αλίσκομαι
 αλαλάζω αλαλιάζω αλαργάρω αλαργέρνω αλαργεύω αλατίζω αλαφιάζομαι αλαφιάζω
 αλαφρώνω αλγώ αλείβομαι αλείβω αλείφομαι αλείφω αλεγράρω αλετρίζω αλευρογυρίζω
 αλευροπασπαλίζω αλευροποιώ αλευροσακιάζω αλευροσταυρώνω αλευρώνω αληθεύω
 αλητεύω αλιεύω αλκοτεστάρω αλλάζω αλλαξοδρομώ αλλαξοπιστώ αλληγορώ αλληθωρίζω
 αλληλεπικαλύπτομαι αλληλεπικρίνομαι αλληλοβοηθιέμαι αλληλοβοηθούμαι
 αλληλογαμιέμαι αλληλογραφώ αλληλοδανείζομαι αλληλοδιαπλέκομαι
 αλληλοεξουδετερώνω αλληλομαχαιρώνομαι αλληλοπαρορμώμαι αλληλοσκοτώνομαι
 αλληλουχώ αλλοιώνομαι αλλοιώνω αλλοτριώνω αλλοφρονώ αλμυρίζω αλυσιδώνω
 αλυσοδένω αλυσώνω αλυχτώ αλφαβητίζω αλφαδιάζω αλωνίζω αμέλγω αμαλγαμώνω
 αμαρτάνω αμαρταίνω αμαυρώνω αμβλύνω αμβλώνω αμείβομαι αμείβω αμελώ αμερικανίζω
 αμεροληπτώ αμιλλώμαι αμμοβολώ αμμοστρώνω αμνηστεύω αμνώγω αμολάω αμολέρνω
 αμολώ αμπαλάρω αμπαρώνω αμπελουργώ αμπελοφιλοσοφώ αμποδένω αμπώθω αμπώνω
 αμφιβάλλω αμφιρρέπω αμφισβητούμαι αμφισβητώ αμφιταλαντεύομαι αμόνω αμύνομαι
 ανάβω ανάγω ανάπτω ανάσσω ανάσχομαι ανάσχω ανάφτω ανέρχομαι ανέχομαι ανήκω
 αναβάλλεται αναβάλλω αναβαίνω αναβαθμίζομαι αναβαθμίζω αναβαθμολογώ αναβαπτίζω
 αναβαφτίζω αναβιβάζομαι αναβιβάζω αναβιώ αναβιώνω αναβλέπω αναβλύζω αναβολίζω
 αναβοώ αναβράζω αναβρυώ αναβρύζω αναγέρνω αναγαλλιάζω αναγγέλλω αναγελώ
 αναγεννώ αναγινώσκω αναγκάζομαι αναγκάζω αναγνωρίζομαι αναγνωρίζω αναγνώθω
 αναγομώνω αναγορεύω αναγουλιάζω αναγράφομαι αναγράφω αναγραμματίζω αναδένω
 αναδίδω αναδίνω αναδακρυώνω αναδαμαλίζω αναδασώνω αναδείχνω αναδεικνύω αναδεύω
 αναδημοσιεύομαι αναδημοσιεύω αναδιανέμω αναδιαρθρώνω αναδιατάσσω αναδιατυπώνω
 αναδιοργανώνω αναδιπλασιάζω αναδιπλώνομαι αναδιπλώνω αναδιφώ αναδομώ αναδύομαι
 αναζωογονούμαι αναζωογονώ αναζωπυρώνω αναθάλλω αναθέτω αναθαρρεύω αναθαρρώ
 αναθερμαίνω αναθεωρώ αναθιβάλλω αναθρέφω αναθρώσκω αναθυμάμαι αναθυμίζω
 αναθυμώ αναιρώ αναισθητοποιούμαι αναισθητοποιώ ανακάθομαι ανακάμπτω ανακαθίζω
 ανακαλύπτω ανακαλώ ανακαρώνω ανακαταλαμβάνω ανακατασκευάζομαι ανακατασκευάζω
 ανακατευθύνω ανακατεύομαι ανακατεύω ανακατώνω ανακεφαλαιώνω ανακηρύσσω
 ανακινώ ανακλίνω ανακλαδίζομαι ανακλαδίζω ανακλαδώνομαι ανακλαδώνω ανακλώ
 ανακοινώνω ανακουφίζομαι ανακουφίζω ανακράζω ανακρίνω ανακριβολογώ ανακρούω
 ανακυκλώνω ανακόπτω ανακύπτω αναλάμπω αναλίσκω αναλαβαίνω αναλαμβάνομαι
 αναλιώνω αναλογίζομαι αναλογώ αναλύομαι αναλύω αναλώνομαι αναλώνω αναμέλπω
 αναμένω αναμαλλιάζω αναμασώ αναμειγνύομαι αναμειγνύω αναμερίζω αναμεταδίδω
 αναμετρώ αναμηρυκάζω αναμιγνύομαι αναμιγνύω αναμισθώνω αναμορφώνω αναμοχλεύω
 ανανήφω ανανεώνομαι ανανεώνω ανανογιέμαι αναντρανίζω αναξέω αναξαίνω
 αναξύω αναπάλλομαι αναπάλλω αναπέμπω αναπαλαιώνω αναπαράγομαι αναπαράγω
 αναπαριστάνω αναπαριστώ αναπαύομαι αναπαύω αναπετώ αναπηδώ αναπιάνω αναπλάθω
 αναπλέω αναπλειστηριάζω αναπληρώνω αναπλωρίζω αναπνέω αναποδιάζω αναποδογυρίζω
 αναπροσαρμόζομαι αναπροσαρμόζω αναπροσλαμβάνω αναπτερώνω αναπτύσσομαι
 αναπυρώνομαι αναπυρώνω αναρίχνω αναριγώ αναριεύω αναρπάζω αναρρίχνω αναρριπίζω
 αναρριχώμαι αναρροφώ αναρρώνω αναρτώ αναρτώμαι αναρχούμαι αναρωτιέμαι αναρωτώ
 ανασαλεύω ανασηκώνομαι ανασηκώνω ανασκάβω ανασκάπτομαι ανασκάπτω ανασκάφτω
 ανασκαλώνω ανασκελώνομαι ανασκελώνω ανασκευάζω ανασκιρτώ ανασκολοπίζω ανασκοπώ
 ανασκουμπώνω ανασπάζομαι ανασπώ αναστέλλομαι αναστέλλω αναστήνω ανασταίνομαι
 αναστατώνομαι αναστατώνω αναστενάζω αναστηλώνω αναστομώνω αναστορούμαι
 αναστρέφομαι αναστρέφω αναστυλώνω ανασυγκροτώ ανασυνδέω ανασυνθέτω ανασυνιστώ
 ανασυστήνω ανασυσταίνω ανασχηματίζω ανασύρομαι ανασύρω ανατέλλω ανατέμνω
 αναταράζω αναταράσσω ανατείνω ανατιμολογώ ανατιμώ ανατιμώμαι ανατινάζομαι
 ανατινάσσω ανατοκίζω ανατοποθετώ ανατρέπομαι ανατρέπω ανατρέφω ανατρέχω
 ανατροφοδοτώ ανατσουτσουρώνω ανατυπώνω αναφέρομαι αναφέρω αναφαίνομαι
 αναφλέγω αναφτερώνω αναφυτεύω αναφωνώ αναφύομαι αναχαιτίζω αναχαράζω
 αναχωματίζω αναχωματώνω αναχωνεύω αναχωρώ αναψηλαφώ αναψοκοκκινίζω
 αναψυχώνω αναψύχω ανδρίζομαι ανδραγαθώ ανδραποδίζω ανδρειεύω ανδρειώνομαι
 ανδροκρατούμαι ανδροφέρνω ανδρώνομαι ανδρώνω ανεβάζω ανεβαίνω ανεβοκατεβάζω
 ανεγείρω ανελκύω ανεμίζω ανεμοδέρνομαι ανεμοδέρνω ανεμπαίζω ανενεργοποιώ
 ανεξαρτητοποιώ ανεξικακώ ανερευνώ ανεσαίνω ανεστορούμαι ανευθυνολογώ ανευρίσκω
 ανεφοδιάζω ανησυχώ ανηφορίζω ανηφορώ ανθίζομαι ανθίζω ανθίσταμαι ανθοβολώ
 ανθολογώ ανθοστολίζω ανθοφορώ ανθρακώνω ανθρωπεύω ανθυπομειδιώ ανθώ ανιδρύω
 ανιχνεύω ανιώ ανοίγω ανοηταίνω ανοιγοκλείνω ανοιγοκλειώ ανοικοδομώ ανομοιώνω
 ανορθώνω ανορύσσω ανοσιουργώ ανοσοποιώ ανοστίζω ανοσταίνω ανοστεύω αντέχω
 ανταγαπώ ανταγωνίζομαι ανταδικώ ανταλλάζω ανταλλάσσω ανταμείβω ανταμώνω
 ανταπαιτώ ανταπαντώ ανταπεργώ ανταποδίδω ανταποδίνω ανταποδείχνω ανταποδεικνύω
 ανταπολογούμαι ανταριάζω αντασφαλίζω αντεκδικούμαι αντενδείκνυμαι αντενεργώ
 αντεξετάζω αντεπαναστατώ αντεπεξέρχομαι αντεπιτίθεμαι αντευχαριστώ αντεύχομαι
 αντηχώ αντιβαίνω αντιβγαίνω αντιβουίζω αντιβοώ αντιγνωμώ αντιγράφω αντιγυρίζω
 αντιδιαδηλώνω αντιδιαστέλλω αντιδικώ αντιδονώ αντιδρώ αντιζυγίζω αντιζυγιάζω
 αντικαθίσταμαι αντικαθιστώ αντικαθρεφτίζομαι αντικαθρεφτίζω αντικαταβάλλω
 αντικατοπτρίζομαι αντικατοπτρίζω αντικειμενοποιώ αντικινητροδοτώ αντικρίζω
 αντικόβω αντικόφτω αντιλάμπω αντιλέγω αντιλαλώ αντιλαμβάνομαι αντιλαμπίζω
 αντιλογώ αντιμάχομαι αντιμεταθέτω αντιμετατίθεμαι αντιμετριέμαι αντιμετριούμαι
 αντιμετωπίζομαι αντιμετωπίζω αντιμιλώ αντιπαθώ αντιπαλαίω αντιπαλεύω
 αντιπαρέχω αντιπαραβάλλω αντιπαραθέτω αντιπαρατάσσω αντιπερισπώ αντιπερνώ
 αντιπολιτεύομαι αντιπράττω αντιπροσκαλώ αντιπροσφέρω αντιπροσωπεύω
 αντιρροπίζω αντισκόβω αντιστέκομαι αντισταθμίζω αντιστηρίζω αντιστοιχίζω
 αντιστρέφομαι αντιστρέφω αντιστρατεύομαι αντιστυλώνω αντιτίθεμαι αντιτείνω
 αντιφέγγω αντιφεγγίζω αντιφρονώ αντιφωνώ αντιχαιρετίζω αντιχαιρετώ αντιχτυπώ
 αντραλίζω αντραλεύω αντραλώνω αντρανίζω αντρειεύομαι αντρειεύω αντρειώνω
 αντροφέρνω αντρώνομαι αντρώνω ανυμνώ ανυπομονεύω ανυπομονώ ανυφαίνω ανυψώνομαι
 ανωκυκλώνω ανωνυμογραφώ αξίζω αξαίνω αξιολογούμαι αξιολογώ αξιοποιώ αξιώ
 αξιώνω αοριστολογώ απάγω απάδω απάτα απέρχομαι απέχω απαγγέλλω απαγγέλνω
 απαγκιστρώνομαι απαγκιστρώνω απαγορεύεται απαγορεύω απαγχονίζω απαθανατίζω
 απαισιοδοξώ απαιτούμαι απαιτώ απαλαίνω απαλείφω απαλλάσσομαι απαλλάσσω
 απαλλοτριώνω απαλογέρνω απαλύνω απαμινώνω απανθίζω απανθρακώνομαι απανθρακώνω
 απαντεχαίνω απαντλώ απαντώ απαξιώ απαξιώνω απαρέσκω απαργυρώνω απαριθμώ
 απαρνιούμαι απαρνούμαι απαρτίζομαι απαρτίζω απαρχαιώνω απασβεστώνω απαστράπτω
 απασχολώ απατά απατώ απατώμαι απαυγάζω απαυδώ απαυτώνω απεγκλωβίζω απειθαρχώ
 απεικάζω απεικονίζομαι απεικονίζω απειλώ απεκδέχομαι απεκδύομαι απεκδύω
 απελαύνω απελευθερώνομαι απελευθερώνω απελπίζομαι απελπίζω απεμπλέκω απεμπολώ
 απενεργοποιώ απενοχοποιώ απεξαρτώ απεραντολογώ απεργάζομαι απεργώ
 απευαισθητοποιώ απευθύνομαι απευθύνω απεχθάνομαι απεύχομαι απηχώ απιθώνω
 απισχναίνω απλοποιούμαι απλοποιώ απλουστεύω απλώνομαι απλώνω αποβάλλομαι
 αποβαίνω αποβαρβαρώνω αποβιβάζω αποβιομηχανίζω αποβιώ αποβιώνω αποβλέπω
 αποβουτυρώνω αποβράζω απογίνομαι απογαλακτίζομαι απογαλακτίζω απογειώνω
 απογοητεύομαι απογοητεύω απογράφω απογραφειοκρατικοποιώ απογριφώνω απογυμνώνω
 αποδίδομαι αποδίδω αποδίνω αποδασώνω αποδείχνω αποδεικνύομαι αποδεικνύω
 αποδεκατίζω αποδελτιώνω αποδεσμεύω αποδημώ αποδιαλέγομαι αποδιαλέγω
 αποδιαλύω αποδιαρθρώνω αποδιαφωτίζω αποδιδράσκω αποδιεθνοποιώ αποδιοργανώνω
 αποδιώχνω αποδοκιμάζομαι αποδοκιμάζω αποδομώ αποδραματοποιώ αποδρώ
 αποδυναμώνω αποδύομαι αποεθνικοποιώ αποειδικεύομαι αποενοποιώ αποεπενδύω
 αποζητώ αποζουρλαίνω αποζώ αποθέτω αποθαίνω αποθαλασσώνομαι αποθαλασσώνω
 αποθαυμάζω αποθεματοποιώ αποθερίζω αποθεραπεύω αποθερμαίνω αποθεώνω αποθηκεύω
 αποθηριώνω αποθησαυρίζω αποθνήσκω αποθορυβοποιώ αποθρασύνομαι αποθρασύνω
 αποικίζω αποικοδομώ αποικώ αποκάμνω αποκάνω αποκαθίσταμαι αποκαθαίρω
 αποκαθιστώ αποκαλύπτω αποκαλώ αποκαρδιώνω αποκαρτερώ αποκαρώνω αποκατασταίνω
 αποκερατώνω αποκεφαλίζω αποκηρύττω αποκηρύχνω αποκλίνω αποκλείω αποκληρώνω
 αποκλιμακώνω αποκοιμίζω αποκοιμιέμαι αποκοιμώμαι αποκολλώ αποκομίζω
 αποκορυφώνω αποκοτώ αποκουτιαίνω αποκρίνομαι αποκραίνομαι αποκρατικοποιώ
 αποκρούω αποκρυπτογραφώ αποκρυσταλλώνω αποκρύβω αποκρύπτω αποκτάω αποκτηνώνω
 αποκωδικοποιώ αποκόβομαι αποκόβω αποκόπτομαι αποκόπτω απολήγω απολαβαίνω
 απολαμβάνω απολαύω απολείπομαι απολείπω απολειτουργώ απολεπίζω απολησμονιέμαι
 απολιθώνω απολινώ απολιπαίνω απολιχνίζω απολλύω απολογιέμαι απολογιούμαι
 απολυμαίνω απολυτρώνω απολωλαίνω απολύω απομένω απομαγεύω απομαγνητίζω
 απομακρύνομαι απομακρύνω απομιμούμαι απομνήσκω απομνημονεύω απομονώνω
 απομυζώ απομυθοποιούμαι απομυθοποιώ απομωραίνω απονέμω απονίβω απονίπτω
 αποναζιστικοποιώ αποναρκώνω απονεκρώνω απονευρώνω απονηώνω απονιτρώνω
 απονυχτερεύω αποξέω αποξαίνω αποξενούμαι αποξενώνω αποξεραίνω αποξεχνιέμαι
 αποξεχνώ αποξηλώνω αποξηραίνω αποξυλώνομαι αποξυλώνω αποξύω αποπέμπω αποπίνω
 αποπαγοποιώ αποπαστρεύω αποπατώ αποπειρώμαι αποπερατώνω αποπλένω αποπλέω
 αποπλανώ αποπληρώνω αποπλύνω αποπνέω αποπνίγω αποπνευματώνω αποποινικοποιώ
 αποπολιτικοποιώ αποπροσανατολίζω αποπροσωποποιώ αποπτύω αποπυρηνικοποιώ
 αποπωματίζω απορρέω απορρίπτω απορρίχνω απορροφάω απορροφώ απορροφώμαι
 απορρυπαίνω απορφανίζω απορώ αποσαθρώνω αποσαπίζω αποσαρώνω αποσαφηνίζω
 αποσβήνω αποσβεννύω αποσβολώνομαι αποσβολώνω αποσείω αποσιωπώ αποσκίζω
 αποσκεπάζω αποσκιρτώ αποσκληραίνομαι αποσκληραίνω αποσκληρύνομαι αποσκληρύνω
 αποσκορακίζω αποσκυβαλίζω αποσμήχω αποσοβώ αποσπερματίζω αποσπώ αποσπώμαι
 αποστάζω αποστέλλομαι αποστέλλω αποστέργω αποσταίνω αποσταθεροποιούμαι
 αποσταλάζω αποστασιοποιούμαι αποστατώ αποστεγνώνω αποστειρώνω αποστερεύω
 αποστεώνω αποστηθίζω αποστομώνω αποστρέφομαι αποστρέφω αποστραβώνω
 αποστρακίζομαι αποστρακίζω αποστρατεύω αποστρατικοποιώ αποστρατιωτικοποιώ
 αποσυγχρονίζω αποσυμπιέζω αποσυμφορίζω αποσυμφορώ αποσυναρμολογούμαι
 αποσυνδέω αποσυνθέτω αποσυντίθεμαι αποσυντονίζομαι αποσυσχετίζω αποσφαλματώνω
 αποσχίζομαι αποσχίζω αποσχηματίζω αποσύρομαι αποσύρω αποσώνω αποτάσσω αποτέμνω
 αποτίω αποταμιεύω αποταυρίζομαι αποτείνομαι αποτείνω αποτελειώνω αποτελματώνω
 αποτελώ αποτεφρώνω αποτιμώ αποτινάζω αποτινάσσω αποτοιχίζω αποτολμάω αποτολμώ
 αποτρέπω αποτραβώ αποτρελαίνω αποτριχώνω αποτροπιάζομαι αποτροπιάζω αποτρυγώ
 αποτυγχάνω αποτυμπανίζω αποτυπώνω αποτυχαίνω απουσιάζω αποφέρω αποφαίνομαι
 αποφασίζω αποφεύγω αποφλοιώνω αποφοιτώ αποφορτίζω αποφουρνίζω αποφράζω
 αποφυλακίζω αποχαιρετάω αποχαιρετίζω αποχαιρετιέμαι αποχαιρετώ αποχαλινώνομαι
 αποχαλώ αποχαρακτηρίζω αποχαυνώνομαι αποχαυνώνω αποχετεύω αποχλωριώνω
 αποχρωματίζομαι αποχρωματίζω αποχτάω αποχτενίζω αποχτώ αποχωρίζομαι αποχωρίζω
 αποψιλώνω αποψύχω απρακτώ απροσωποποιώ απωθώ απόζω απόκειμαι απόκειται
 αράζω αρέσκομαι αρέσκω αρέσω αραδιάζω αραθυμώ αραιώνω αραξοβολώ αραχνιάζω
 αργαποχαιρετώ αργοκινώ αργοκοιμάμαι αργολογώ αργοξυπνώ αργοπορώ αργοσαλεύω
 αργοταξιδεύω αργώ αρδεύω αρθρογραφώ αρθρώνω αριβάρω αριθμίζω αριθμούμαι αριθμώ
 αριστεύω αρκιέμαι αρκουδίζω αρκούμαι αρκώ αρμέγω αρμαθιάζω αρματώνω αρμενίζω
 αρμυρίζω αρμόζει αρμόζω αρνεύγω αρνεύω αρνιέμαι αρνιούμαι αρνούμαι αροτριώνω
 αρπάχνω αρπίζω αρπακολλώ αρπώ αρραβωνιάζομαι αρραβωνιάζω αρρεβωνιάζομαι
 αρρωστώ αρταίνω αρτιώνω αρτύζω αρτύνω αρφανεύω αρχίζω αρχαΐζω αρχειοθετώ
 αρχινώ αρχοντεύω αρωματίζω αρόω αρύομαι ασβεστοποιώ ασβεστώνω ασεβώ ασελγαίνω
 ασημώνω ασθενώ ασθμαίνω ασκημίζω ασκημαίνω ασκητεύω ασκούμαι ασκώ ασπάζομαι
 ασταρώνω αστεΐζομαι αστειεύομαι αστειολογώ αστερώνω αστικοποιούμαι αστικοποιώ
 αστοχώ αστράφτω αστραποβολώ αστροφέγγω αστυνομεύω αστυνομοκρατούμαι
 ασφαλίζω ασφαλτοστρώνω ασφαλτώνω ασφυκτιώ ασχάλλω ασχημίζω ασχημαίνω ασχημονώ
 ασωτεύω ατακτώ αταχτώ ατενίζω ατιμάζομαι ατιμάζω ατμίζω ατομικεύω ατονώ ατροφώ
 αττικίζω ατυχώ αυγάζω αυγοκόβω αυθαδιάζω αυθαιρετώ αυθυποβάλλομαι αυλακίζω
 αυλακώνω αυνανίζομαι αυξάνομαι αυξάνω αυξαίνω αυξομειώνομαι αυξομειώνω
 αυτενεργώ αυτιάζομαι αυτοαθωώνομαι αυτοαναιρούμαι αυτοανακηρύσσομαι
 αυτοαξιολογούμαι αυτοαποκαλούμαι αυτοβιογραφούμαι αυτοδεσμεύω αυτοδιαλύομαι
 αυτοδιαψεύδομαι αυτοδικώ αυτοδιοικούμαι αυτοδιορίζομαι αυτοδιπλασιάζομαι
 αυτοελέγχομαι αυτοεξορίζομαι αυτοεπαινούμαι αυτοθαυμάζομαι αυτοθυσιάζομαι
 αυτοκαθαρίζομαι αυτοκαθορίζω αυτοκακολογούμαι αυτοκαταδικάζομαι αυτοκαταργώ
 αυτοκοροϊδεύομαι αυτοκριτικάρομαι αυτοκτονώ αυτοκυβερνιέμαι αυτοκυβερνώμαι
 αυτομαστιγώνομαι αυτοματοποιώ αυτομολώ αυτονομάζομαι αυτονομούμαι
 αυτοπαραπέμπομαι αυτοπαρηγοριέμαι αυτοπαρηγορούμαι αυτοπαρουσιάζομαι
 αυτοπραγματοποιούμαι αυτοπραγματώνομαι αυτοπροβάλλομαι αυτοπροσωπογραφούμαι
 αυτοπυρπολούμαι αυτοσυγκρατούμαι αυτοσυγχαίρομαι αυτοσυντηρούμαι
 αυτοσχεδιάζω αυτοτιμωρούμαι αυτοτιτλοφορούμαι αυτοτραυματίζομαι
 αυτοφωτογραφίζομαι αυτοφύομαι αυτοχαρακτηρίζομαι αυτοχειριάζομαι
 αυτοχρηματοδοτούμαι αυτοϊκανοποιούμαι αυτοϋπονομεύομαι αφήνομαι αφήνω
 αφαιμάσσω αφαιρούμαι αφαιρώ αφαλοκόβω αφανίζω αφαρπάζω αφελληνίζομαι
 αφεντεύω αφερματίζω αφηγούμαι αφηνιάζω αφηρωίζω αφθονώ αφιερώνω αφικνούμαι
 αφιονίζω αφιππεύω αφισοκολλώ αφλογιστώ αφογκράζομαι αφοδεύω αφομοιώνομαι
 αφοπλίζω αφορίζω αφορμίζω αφορμώμαι αφορώ αφοσιώνομαι αφουγκράζομαι αφρίζω
 αφροστεφανώνω αφρουκούμαι αφτιάζομαι αφυγραίνω αφυδατώνομαι αφυδατώνω
 αφυπηρετώ αφυπνίζομαι αφυπνίζω αχαμναίνω αχνίζω αχνοδιαγράφω αχνοτρέμω
 αχνοφωτίζω αχνότρεμος αχολογώ αχρειολογώ αχρηστεύω αχώ αψηφώ αψιδώνω αψιμαχώ
 αψώνω αἰσχροκερδῶ αἰσχρολογῶ βάζω βάλλομαι βάλλω βάνω βάπτω βάφομαι βάφω βέχω
 βαίνω βαβίζω βαβαδίζω βαβαλίζω βαγίζω βαδίζω βαθαίνω βαθμοθετώ βαθμολογώ
 βαθουλώνω βαθύνω βακρύζω βακχίζω βακχεύω βαλαντώνω βαλκανοποιώ βαλσάρω
 βαλτώνω βαπτίζομαι βαπτίζω βαρίσκω βαραίνω βαρβαρίζω βαρβατεύω βαρβατιάζω
 βαριέμαι βαριακούω βαριανασαίνω βαριαναστενάζω βαριεστίζω βαριεστώ
 βαριοκοιμάμαι βαρκούμαι βαρυγκομάω βαρυγκομώ βαρυγκωμάω βαρυγκωμώ βαρυθυμώ
 βαρυκολυώ βαρυπενθώ βαρυστομαχιάζω βαρυφαίνεται βαρύνομαι βαρύνω βαρύχνω βαρώ
 βασίζω βασανίζομαι βασανίζω βασιλεύω βασκάνω βασκαίνω βαστάζω βαστάω βαστιέμαι
 βατεύομαι βατεύω βατσινάρω βατταρίζω βαττολογώ βαυκαλάω βαυκαλίζομαι βαυκαλίζω
 βαφτίζομαι βαφτίζω βγάζω βγάνω βγαίνω βγιάζω βδελύσσομαι βεβαιώνομαι βεβαιώνω
 βεβηλώνω βεγγερίζω βελάζω βελονιάζω βελτιστοποιώ βελτιώνομαι βελτιώνω
 βερνικώνομαι βερνικώνω βηματίζω βιάζομαι βιάζομαι βιαιοπραγώ βιβλιοδετώ
 βιδώνομαι βιδώνω βικιλεξικό:ορισμοί βικιλεξικό:ορισμοί βικιποιώ βιντεοσκοπώ
 βιομηχανοποιώ βιοπορίζομαι βιράρω βιτσίζω βιώνω βκατίζω βλάπτω βλάφτω βλέπομαι
 βλακεύω βλαστάνω βλαστίζω βλασταίνω βλαστημώ βλαστολογώ βλασφημώ βλεπάω
 βλογώ βοήθεια:γρήγορη δημιουργία/ρημ- βοήθεια:διάρθρωση λημμάτων βογκάω
 βογκώ βοηθάω βοηθιέμαι βοηθώ βολίζω βολεί βολεύομαι βολεύω βολιδοσκοπώ
 βολοκοπώ βολτάρω βομβαρδίζω βοσκάω βοσκώ βοστρυχίζω βοστρυχώ βοτανίζω
 βουΐζω βουίζω βουβαίνομαι βουβαίνω βουβιάζω βουκολώ βουλίζομαι βουλίζω
 βουλιάζω βουλιέμαι βουλιμιώ βουλώνομαι βουλώνω βουρβουλακίζω βουρβουλακώ
 βουρλίζω βουρτσίζω βουρώ βουτάω βουτυρώνω βουτώ βούλομαι βοώ βράζω βρέχει
 βρέχω βρίζομαι βρίζω βρίθω βρίσκομαι βρίσκω βραβεύομαι βραβεύω βραδιάζει
 βραδυγλωττώ βραδυπορώ βραδύνω βρακώνομαι βραχνιάζω βραχυκυκλώνω βραχυλογώ
 βρεφοκομώ βρικολακιάζω βρομάω βρομίζω βρομοκοπάω βρομοκοπώ βρομώ βροντάω
 βροντοφωνάζω βροντοφωνώ βροντώ βρυχιέμαι βρυχώμαι βρωμάω βυζάνω βυζαίνω
 βυθάω βυθίζομαι βυθίζω βυθοκορώ βυθομετρώ βυθοσκοπώ βυθώ βυνοποιώ βυσματώνω
 βωμολοχώ βόσκω γένομαι γέρνω γίνομαι γαβγίζω γαβλίζω γαγγραινιάζω
 γαζώνω γαλακτοποιώ γαλακτωματοποιώ γαλβανίζω γαληνεύω γαληνιάζω γαλονάρω
 γαλονοφορώ γαλουχούμαι γαλουχώ γαλώνω γαμάω γαμιέμαι γαμπρίζω γαμώ γανιάζω
 γαντζώνω γανώνω γαργαλάω γαργαλίζω γαργαλεύω γαργαλιέμαι γαργαλώ γαργαρίζω
 γαρνίρω γαστρώνω γατσιάζω γαυριάζω γαυριώ γαϊτανώνω γγαστρώνομαι γγαστρώνω
 γδέρνω γδικιέμαι γδύνω γειτνιάζω γειτονεύω γειώνω γελιέμαι γελοιογραφώ
 γελοιοποιώ γελώ γεμίζω γεμόζω γενικεύομαι γενικεύω γενικολογώ γεννάω γεννιέμαι
 γεννώ γεράζω γεραίρω γερεύω γερνάω γερνώ γεροκομώ γευματίζω γεφυρώνω γεύομαι
 γηράσκω γηροκομώ γητεύω γιαίνω γιανίσκω γιαουρτώνω γιαρατίζω γιατρεύομαι
 γιατροπορεύομαι γιατροπορεύω γιγαντεύω γιγαντώνω γινατεύω γινώσκω γιομάζω
 γιομόζω γιορτάζομαι γιορτάζω γιουτώ γιουχάρω γιουχαΐζω γιώνω γκαβίζω γκαζώνω
 γκαρίζω γκαστρώνω γκεζεράω γκεζερίζω γκιζεράω γκιζερίζω γκλασάρω γκουγκλάρω
 γκρεμίζομαι γκρεμίζω γκρεμοτσακίζομαι γκριζάρω γκρινιάζω γκρουπάρω γκώνω γλακώ
 γλασάρω γλαυκώνω γλαφυραίνω γλείφομαι γλείφω γλεντάω γλεντοκοπάω γλεντοκοπώ
 γλιστράω γλιστρώ γλιτώνω γλυκίζω γλυκαίνομαι γλυκαίνω γλυκοβραδιάζει
 γλυκοκοιμάμαι γλυκοκοιτάζω γλυκοκουβεντιάζω γλυκομιλώ γλυκοσαλίζω γλυκοσαλιάζω
 γλυκοφέγγει γλυκοφιλάω γλυκοφιλώ γλυκοχαράζει γλυμίζω γλυτώνω γλυφίζω γλυφαίνω
 γλωσσοτρώω γλωσσοφιλώ γλύφω γνέθω γνέφω γνοιάζει γνοιάζομαι γνωματεύω
 γνωμολογώ γνωρίζομαι γνωρίζω γνωστεύω γνωστοποιούμαι γνωστοποιώ γογγύζω
 γομώ γομώνω γονατίζω γονιμοποιούμαι γονιμοποιώ γονυπετώ γουβιάζω γουβώνω
 γουρλώνω γουρμάζω γουρουνίζω γουρσουζεύω γουστάρω γράφω γραδάρω
 γραμμογραφώ γραμμοσκιάζω γραμμώνω γραντίζω γραπώνομαι γραπώνω γρασάρω
 γρατζουνίζω γρατζουνώ γρατσουνάω γρατσουνίζω γρατσουνώ γρηγορώ γρικώ γρινιάζω
 γριπώνομαι γροικώ γρονθοκοπώ γρουσουζεύω γρούζω γρυλίζω γρυλλίζω γρύζω γρύζω
 γυαλοκοπώ γυμνάζω γυμνητεύω γυμνώνω γυναικοκρατούμαι γυναικοφέρνω γυρίζω
 γυρνώ γυροφέρνω γυψώνω γωνιάζω δάκνω δένω δέομαι δέρνομαι δέρνω δέχομαι δέω
 δίνομαι δίνω δαγκάνομαι δαγκάνω δαγκώνομαι δαγκώνω δαιμονίζομαι δαιμονίζω
 δαιμονολογώ δαιμονοποιώ δακρυρροώ δακρύζω δακτυλογραφούμαι δακτυλογραφώ δαμάζω
 δανείζομαι δανείζω δανειοδοτώ δαπανώ δαπανώμαι δασκαλεύω δασμολογώ δασύνομαι
 δασώνω δαφνοστεφανώνομαι δαφνοστεφανώνω δαχτυλογραφώ δείχνομαι δείχνω δείχτω
 δειγματίζω δεικνύω δειλιάζω δεινοπαθώ δειπνώ δεκάζω δεκαπλασιάζω δεκαρολογώ
 δελεάζω δεματίζω δεματιάζω δενδροφυτεύω δεντροφυτεύομαι δεντροφυτεύω δεντρώνω
 δεσμεύομαι δεσμεύω δεσπόζω δευτερολογώ δευτερώνω δηγιέμαι δηλητηριάζομαι
 δηλοποιώ δηλώνω δημαγωγώ δημαρχεύω δημαρχώ δημεύω δημηγορώ δημιουργούμαι
 δημοκοπώ δημοκρατούμαι δημοπρατούμαι δημοπρατώ δημοσιεύομαι δημοσιεύω
 δημοσιοποιούμαι δημοσιοποιώ δημοσκοπώ δημοτικίζω δηώ δηώνω διάγω διάζομαι
 διέπω διέρχομαι διίσταμαι διαβάζομαι διαβάζω διαβάλλομαι διαβάλλω διαβαίνω
 διαβεβαιώνω διαβιβάζομαι διαβιβάζω διαβιβρώσκω διαβιώ διαβιώνω διαβλέπω
 διαβουκολώ διαβουλεύομαι διαβρέχω διαβρέχω διαβρώνω διαγγέλλω διαγιγνώσκω
 διαγουμίζομαι διαγουμίζω διαγράφομαι διαγράφω διαγραμμίζω διαγωνίζομαι
 διαδίδομαι διαδίδω διαδίνομαι διαδίνω διαδηλώνω διαδραματίζεται
 διαδραματίζω διαζευγνύω διαζώνω διαθέτω διαθερμαίνω διαθλώ διαθρυλώ διαιρώ
 διαιτητεύω διαιτώ διαιτώμαι διαιωνίζομαι διαιωνίζω διακανονίζω διακατέχομαι
 διακηρύσσω διακηρύττω διακηρύττω διακηρύχνω διακινδυνεύω διακινώ διακλαδίζω
 διακοινώνω διακομίζω διακονεύω διακονώ διακορεύω διακοσμώ διακρίνομαι διακρίνω
 διακτινίζω διακυβερνώ διακυβεύω διακυμαίνομαι διακωδικοποιώ διακωμωδώ
 διακόπτω διαλάμπω διαλέγομαι διαλέγω διαλαλώ διαλαμβάνω διαλανθάνω διαλείπω
 διαλευκαίνω διαλλάσσομαι διαλλάσσω διαλογίζομαι διαλύζω διαλύομαι διαλύω
 διαμένω διαμαρτυρώ διαμαρτύρομαι διαμείβομαι διαμείβω διαμελίζω διαμερίζω
 διαμεσολαβώ διαμετακομίζω διαμετρώ διαμηνύω διαμηχανώμαι διαμιλλώμαι
 διαμορφώνομαι διαμορφώνω διαμφισβητώ διανέμομαι διανέμω διανεμίζω διανεύω
 διανθώ διανοίγω διανοούμαι διανυκτερεύω διανυχτερεύω διανύω διαολίζω
 διαπαιδαγωγώ διαπεραιώνομαι διαπεραιώνω διαπερνάω διαπερνώ διαπιστεύομαι
 διαπιστώνομαι διαπιστώνω διαπλάθω διαπλάσσω διαπλέκω διαπλέω διαπλατύνω
 διαπνέομαι διαπομπεύω διαπορθμεύω διαπορώ διαποτίζω διαπράττω διαπρέπω
 διαπυούμαι διαρθρώνω διαρκώ διαρμίζω διαρπάζω διαρρέω διαρρήχνω διαρρηγνύω
 διασαλεύω διασαφηνίζω διασαφώ διασείω διασκέπτομαι διασκεδάζομαι διασκεδάζω
 διασκευάζω διασκορπίζομαι διασκορπίζω διασκορπώ διασπαθίζω διασπείρω διασπώ
 διαστέλλομαι διαστέλλω διαστίζω διασταυρώνομαι διασταυρώνω διαστρέφω
 διασυμπεριλαμβάνω διασυνδέω διασφαλίζω διασχίζω διασύρω διασώζω διατάζομαι
 διατάσσομαι διατάσσω διατέμνω διατίθεμαι διαταράζω διαταράσσω διατείνομαι
 διατηρούμαι διατηρώ διατηρῶ διατιμώ διατρέφομαι διατρέφω διατρίβω διατρανώνω
 διατυμπανίζω διατυπώνω διαυγάζω διαφέγγω διαφέρομαι διαφέρω διαφαίνομαι
 διαφεύγω διαφημίζομαι διαφημίζω διαφθείρω διαφιλονικώ διαφορίζω
 διαφοροποιώ διαφυλάγω διαφυλάσσω διαφυλάττω διαφωνώ διαφωτίζω διαχέομαι διαχέω
 διαχαράσσω διαχειμάζω διαχειρίζομαι διαχωρίζομαι διαχωρίζω διαχύνω διαψεύδομαι
 διαψύχω διβολίζω διδάσκομαι διδάσκω διεγείρω διεθνοποιούμαι διεθνοποιώ
 διεκδικώ διεκπεραιώνω διεκτραγωδώ διελέγχω διεμβάλλω διεμβολίζω διενεργώ
 διεξάγω διεξέρχομαι διερευνώ διερμηνεύω διερωτώμαι διευθετώ διευθύνομαι
 διευκολύνω διευκρινίζω διευκρινώ διευρύνομαι διευρύνω διηγιέμαι διηγούμαι
 διημερεύω διισχυρίζομαι δικάζω δικαιοδοτώ δικαιολογούμαι δικαιολογώ δικαιούμαι
 δικαιώνω δικηγορώ δικλώ δικρανίζω δικτυώνομαι δικτυώνω διογκούμαι διογκώνομαι
 διοικητικοποιώ διοικούμαι διοικώ διολισθαίνω διομολογώ διοπτεύω διορίζομαι
 διοργανώνομαι διοργανώνω διορθώνομαι διορθώνω διορύσσω διορώ διοχετεύομαι
 διπλαρώνω διπλασιάζομαι διπλασιάζω διπλοκλειδώνω διπλοπαρκάρω διπλοψηφίζω
 διπλώνω διποδίζω δισκοβολώ διστάζω δισχίζω διυλίζω διυλίζω διφωσφορυλιώνω
 διχάζω διχαλώνω διχογνομώ διχογνωμονώ διχογνωμώ διχοτομώ διψάω διψώ διώκομαι
 διώχνω δογματίζω δοκιμάζομαι δοκιμάζω δοκοθέτης δοκώ δολιεύομαι δολιχοδρομώ
 δολοφονώ δολώνω δομώ δονκιχωτίζω δονούμαι δονώ δοξάζομαι δοξάζω δοξαπατρίζω
 δοξολογώ δουλεύομαι δουλεύω δράττομαι δράχνω δρέπω δραματοποιούμαι δραματοποιώ
 δρασκελίζω δρασκελώ δραστηριοποιούμαι δραστηριοποιώ δραχμοποιώ δρεπανίζω
 δρομολογώ δροσίζομαι δροσίζω δροσερεύω δροσολογούμαι δροσολογώ δρω δυναμιτίζω
 δυναστεύω δυσανασχετώ δυσαρεστούμαι δυσαρεστώ δυσθυμώ δυσκολεύομαι δυσκολεύω
 δυσπιστώ δυστοκώ δυστροπώ δυστυχώ δυσφημίζω δυσφημώ δυσφορώ δυσχεραίνω δωρίζω
 δωροδοκώ δωροληπτώ δωρώ δύναμαι δύνομαι δύω δώνω είθισται είμαι εγγίζω
 εγγράφομαι εγγράφω εγγυοδοτώ εγγυούμαι εγγυώμαι εγείρω εγκαθίσταμαι εγκαθιδρύω
 εγκαινιάζω εγκαλούμαι εγκαλώ εγκαρδιώνω εγκαρτερώ εγκαταβιώ εγκαταβιώνω
 εγκαταλείπω εγκατασπείρω εγκατασταίνω εγκεντρίζω εγκιβωτίζω εγκλίνομαι εγκλείω
 εγκλιματίζομαι εγκλιματίζω εγκλωβίζω εγκολλώ εγκολπώνομαι εγκρίνω εγκυμονώ
 εγκωμιάζομαι εγκωμιάζω εγκύπτω εγχέω εγχαράσσω εγχειρίζω εγχειρώ εδέησα
 εδράζω εδραιώνω εδρεύω εθίζω εθελοτυφλώ εθνικοποιούμαι εθνικοποιώ ειδικεύομαι
 ειδοποιούμαι ειδοποιώ ειδωλοποιώ εικάζω εικονίζω εικονογραφώ εικοτολογώ
 ειμί ειρηνεύω ειρωνεύομαι εισάγομαι εισάγω εισέρχομαι εισέχω εισαγγελεύω
 εισακούω εισβάλλω εισδύω εισηγούμαι εισκομίζω εισοδηματοποιώ εισοδιάζω εισορμώ
 εισπνέω εισπράττω εισρέω εισροφώ εισφέρω εισχωρώ εκατοστίζω εκβάλλω εκβαίνω
 εκβαρβαρώνω εκβιάζω εκβιομηχανίζω εκβλαστάνω εκβράζω εκβραχίζω εκγηπεδώνω
 εκδέρω εκδίδομαι εκδίδω εκδασώνω εκδηλώνομαι εκδηλώνω εκδημοκρατίζω εκδημώ
 εκδικιέμαι εκδικούμαι εκδιώκω εκδράμω εκδύω εκθέτω εκθαμβώνω εκθειάζω
 εκθηλύνομαι εκθηλύνω εκθλίβω εκθρονίζομαι εκθρονίζω εκκαθαρίζω εκκαλώ
 εκκενώνω εκκινώ εκκλησιάζομαι εκκοκκίζω εκκολάπτω εκκρίνω εκκρεμώ εκλέγω
 εκλατομώ εκλαϊκεύω εκλείπω εκλεπτύνω εκλιπαρώ εκλογικεύομαι εκλογικεύω εκλύω
 εκμανθάνω εκμαυλίζω εκμεταλλεύομαι εκμηδενίζομαι εκμηδενίζω εκμηχανίζω
 εκμυζώ εκμυστηρεύομαι εκναυλώνω εκνευρίζομαι εκνευρίζω εκπέμπω εκπίπτω
 εκπαιδεύω εκπαραθυρώνω εκπαρθενεύω εκπατρίζομαι εκπηγάζω εκπλέω εκπλήσσομαι
 εκπλήττω εκπλειστηριάζομαι εκπλειστηριάζω εκπληρώνω εκπνέω εκποιούμαι εκποιώ
 εκπονώ εκπορεύομαι εκπορθώ εκπορνεύομαι εκπορνεύω εκπροσωπεύω εκπροσωπούμαι
 εκπτύσσω εκπυρσοκροτώ εκπωματίζω εκρέω εκρήγνυμαι εκριζώνω εκσκάπτω εκσλαβίζω
 εκσπερματώνω εκσπώ εκστασιάζομαι εκστομίζω εκστρατεύω εκσυγχρονίζω
 εκσφενδονίζω εκτίθεμαι εκτίνω εκτίω εκταμιεύω εκτείνομαι εκτείνω εκτελούμαι
 εκτελώ εκτιμώ εκτινάσσω εκτοκίζω εκτονώνομαι εκτονώνω εκτοξεύω εκτοπίζω
 εκτρέπομαι εκτρέπω εκτρέφω εκτραχηλίζομαι εκτραχύνω εκτροχιάζομαι εκτροχιάζω
 εκτυλίσσομαι εκτυλίσσω εκτυπώνομαι εκτυπώνω εκτυφλώνω εκφέρω εκφαυλίζω εκφεύγω
 εκφοβώ εκφορτίζω εκφορτώνω εκφράζομαι εκφράζω εκφυλίζω εκφωνώ εκφόρτιση
 εκφύω εκχέω εκχειλίζω εκχερσώνω εκχιονίζω εκχριστιανίζω εκχυδαΐζω εκχυλίζω
 εκχωρώ εκχύνω εκχύω ελέγχομαι ελέγχω ελίσσομαι ελαιοχρωματίζω ελασματοποιώ
 ελαττώνω ελαφραίνω ελαφρύνω ελαφρώνω ελαχιστοποιούμαι ελαχιστοποιώ ελαύνω
 ελεημονώ ελευθεριάζω ελευθεροκοινωνώ ελευθερώνομαι ελευθερώνω ελεώ ελκύω
 ελληνίζω ελληνογλωττώ ελλιμενίζω ελλοχεύω ελπίζω εμίζω εμβάζω εμβάλλω εμβαθύνω
 εμβολίζω εμβολιάζω εμμένω εμπήγω εμπίπτω εμπαίζω εμπεδώνω εμπεριέχομαι
 εμπιστεύομαι εμπλέκομαι εμπλέκω εμπλουτίζομαι εμπλουτίζω εμπνέω εμποδίζομαι
 εμποιώ εμπορευματοποιούμαι εμπορευματοποιώ εμπορεύομαι εμποτίζω εμπρέπει
 εμφαίνω εμφανίζομαι εμφανίζω εμφατίζω εμφιαλώνω εμφιλοχωρώ εμφορούμαι εμφυσώ
 εμφωλεύω εμψεκάζω εμψυχώνομαι εμψυχώνω εμώ ενάγω ενέχομαι ενέχω ενίσταμαι
 εναγκαλίζομαι εναλλάσσομαι εναλλάσσω ενανθρακώνω εναντιοδρομώ εναντιολογώ
 εναντιώνω εναποθέτω εναποθηκεύω εναπομένω εναπόκειμαι εναπόκειται
 εναρμονίζω ενασκώ ενασμενίζομαι ενασχολούμαι ενατενίζω ενγαλλίζω ενδέχεται
 ενδείκνυμαι ενδημώ ενδιαιτώμαι ενδιατρίβω ενδιαφέρομαι ενδιαφέρω ενδογενοποιώ
 ενδύομαι ενδύω ενεδρεύω ενεργοποιούμαι ενεργοποιώ ενεργώ ενεχυριάζω
 ενηλικιώνω ενημερώνομαι ενημερώνω ενθέτω ενθαρρύνω ενθουσιάζομαι ενθουσιάζω
 ενθρονίζω ενθυλακώνω ενθυμίζω ενθυμούμαι ενθυμώ ενιδρύω ενισχύομαι ενισχύω
 εννοούμαι εννοώ ενοικιάζομαι ενοικιάζω ενοικώ ενοποιούμαι ενοποιώ ενορχηστρώνω
 ενοφθαλμίζω ενοχλούμαι ενοχλώ ενοχοποιούμαι ενοχοποιώ ενσακκίζω ενσαρκώνω
 ενσπείρω ενσταλάζω ενστερνίζομαι ενσφηνώνω ενσωματώνω εντάσσω εντέλλομαι
 εντατικοποιώ ενταφιάζω εντείνω εντοιχίζω εντοπίζω εντρέπομαι εντρίβω
 εντρυφώ εντυπωσιάζομαι εντυπωσιάζω εντυπώνω ενυδατώνω ενυπάρχω ενυπνιάζομαι
 ενωτικεύω ενώνομαι ενώνω εξάγομαι εξάγω εξάπτομαι εξάπτω εξέρχομαι εξέχω
 εξαίρω εξαγγέλλω εξαγγλίζω εξαγιάζω εξαγνίζω εξαγοράζομαι εξαγοράζω
 εξαγριώνω εξαερίζω εξαερώνω εξαθλιώνομαι εξαθλιώνω εξαιρούμαι εξαιρώ
 εξακολουθώ εξακοντίζω εξακριβώνω εξαλείφω εξαλλάσσω εξανίσταμαι εξαναγκάζομαι
 εξανδραποδίζω εξανεμίζομαι εξανεμίζω εξανθρωπίζω εξαντλούμαι εξαντλώ εξαπατάω
 εξαπλασιάζω εξαπλώνομαι εξαπλώνω εξαπολύω εξαποστέλλω εξαργυρώνω εξαρθρώνομαι
 εξαρτάται εξαρτίζω εξαρτιέμαι εξαρτύζω εξαρτώ εξαρτώμαι εξαρχαΐζω εξασθενίζω
 εξασκώ εξασφαλίζω εξατμίζομαι εξατμίζω εξατομικεύω εξαφανίζομαι εξαφανίζω
 εξαχρειώνω εξαϋλώνω εξεγείρομαι εξεγείρω εξειδικεύομαι εξειδικεύω
 εξεικονίζω εξελέγχω εξελίσσομαι εξελίσσω εξελληνίζω εξεμώ εξεργάζομαι
 εξερευνώ εξερευνώμαι εξετάζομαι εξετάζω εξευγενίζω εξευμενίζω εξευρίσκω
 εξευτελίζομαι εξευτελίζω εξηγούμαι εξηγώ εξημερώνομαι εξημερώνω εξιδανικεύω
 εξικνούμαι εξιλεώνομαι εξιλεώνω εξισλαμίζω εξισορροπώ εξιστορώ εξισώνω εξιτάρω
 εξοβελίζω εξογκώνομαι εξογκώνω εξοδεύω εξοικίζω εξοικειώνομαι εξοικειώνω
 εξοκέλλω εξολισθάνω εξολισθαίνω εξολοθρεύω εξομαλίζω εξομαλύνω εξομοιώνω
 εξομολογούμαι εξομολογώ εξονειδίζω εξοντώνομαι εξοντώνω εξονυχίζω εξοπλίζω
 εξοργίζομαι εξοργίζω εξορκίζω εξορμώ εξορύσσομαι εξορύσσω εξοστρακίζομαι
 εξουδετερώνω εξουθενώνομαι εξουθενώνω εξουσιάζω εξουσιοδοτώ εξοφέρω εξοφλούμαι
 εξυβρίζω εξυγιαίνω εξυμνούμαι εξυμνώ εξυπακούεται εξυπηρετούμαι εξυπηρετώ
 εξυφαίνω εξυψώνω εξωθώ εξωραΐζω εξωτερικεύω εορτάζω επάγω επέρχομαι επέστη
 επίκειμαι επίκειται επαίρομαι επαγγέλλομαι επαγρυπνώ επαινούμαι επαινώ επαιτώ
 επακουμβώ επαλείφω επαληθεύομαι επαληθεύω επαμφοτερίζω επανάγω επανέρχομαι
 επαναβλέπω επαναγοράζω επαναδιαπραγματεύομαι επαναδιατάσσω επαναδιατυπώνω
 επαναδιοχετεύω επανακάμπτω επανακαθορίζω επανακρίνω επανακτώ επανακυκλοφορώ
 επαναλαμβάνω επαναλειτουργώ επαναμισθώνω επαναπέμπω επαναπατρίζομαι
 επαναπαύομαι επαναπαύω επαναποστέλλω επαναπροσδιορίζω επαναπροσλαμβάνω
 επαναρχίζω επαναστατικοποιώ επαναστατώ επανασυγκολλώ επανασυγκροτώ
 επανασυναρμολογώ επανασυνδέω επανασχεδιάζω επαναταξινομώ επανατοποθετούμαι
 επαναφέρω επανδρώνομαι επανδρώνω επανεγγράφω επανεγκαθιστώ επανεισάγω
 επανεκλέγω επανεκπαιδεύω επανεμφανίζω επανενεργοποιώ επανεντάσσω επανενώνω
 επανεξετάζω επανεπενδύω επανεπιβεβαιώνω επανιδρύω επανοξειδώνω επανορθώνω
 επαργυρώνω επαρκώ επαυξάνω επαφίεμαι επείγει επείγομαι επείγω επεκτείνομαι
 επελαύνω επεμβαίνω επενδύω επενεργώ επεξεργάζομαι επεξηγώ επερωτώ επευφημώ
 επιβάλλομαι επιβάλλω επιβαίνω επιβαρύνομαι επιβαρύνω επιβεβαιώνομαι
 επιβιβάζομαι επιβιβάζω επιβιώνω επιβλέπω επιβοηθώ επιβουλεύομαι επιβραβεύω
 επιγράφω επιδένω επιδέχομαι επιδίδομαι επιδίδω επιδίνω επιδαψιλεύω
 επιδείχνω επιδεικνύομαι επιδεικνύω επιδεινώνομαι επιδεινώνω επιδημώ επιδικάζω
 επιδιορθώνω επιδιώκω επιδοκιμάζω επιδοτώ επιδράμω επιδρώ επιζητώ επιζώ επιθέτω
 επιθυμώ επικάθημαι επικάθομαι επικαίω επικαθορίζω επικαλούμαι επικαλύπτομαι
 επικαρπώνομαι επικασσιτερώνομαι επικασσιτερώνω επικεντρώνομαι επικεντρώνω
 επικηρώνω επικοινωνικοποιώ επικοινωνώ επικολλώ επικονιάζομαι επικονιάζω
 επικρέμαμαι επικρέμαται επικρίνομαι επικρίνω επικρατεί επικρατώ επικροτώ
 επικυρώνω επικύπτω επιλέγω επιλαμβάνομαι επιλύνω επιλύομαι επιλύω επιμένω
 επιμελούμαι επιμερίζομαι επιμερίζω επιμεταλλώνω επιμετρώ επιμηκύνω επιμολύνω
 επιμορφώνω επινέμω επινεύω επινικελώνω επινοώ επιορκώ επιπάσσω επιπίπτω
 επιπεδώνω επιπλέω επιπλήττω επιπλώνομαι επιπλώνω επιπολάζω επιπωματίζω
 επισείω επισημαίνομαι επισημαίνω επισημοποιούμαι επισημοποιώ επισιτίζω
 επισκευάζομαι επισκευάζω επισκιάζομαι επισκιάζω επισκοπώ επισκοτίζω
 επισπεύδω επιστάζω επιστέφω επιστατώ επιστεγάζω επιστρέφομαι επιστρέφω
 επιστρατεύω επιστρώνω επισυμβαίνω επισυνάπτομαι επισυνάπτω επισφραγίζω
 επισύρω επιτάσσω επιτέλλω επιτίθεμαι επιταχύνομαι επιταχύνω επιτείνω επιτελώ
 επιτηρώ επιτιμώ επιτρέπεται επιτρέπω επιτρέχω επιτροπεύω επιτυγχάνω επιτυχαίνω
 επιφαίνομαι επιφοιτώ επιφορτίζομαι επιφορτίζω επιφυλάσσομαι επιφυλάσσω
 επιχαλκώνω επιχειρηματολογώ επιχειρώ επιχορηγώ επιχρίω επιχρυσώνω επιχρωματίζω
 επιχωριάζω επιχώνω επιψαύω εποικίζω εποικοδομώ εποικώ επονομάζω εποπτεύω
 εποφθαλμιώ εποφθαλμιώμαι εποχούμαι επωάζομαι επωάζω επωμίζομαι επωφελούμαι
 ερανίζομαι εργάζομαι εργοδοτώ εργώ ερείδομαι ερεθίζομαι ερεθίζω ερειπώνομαι
 ερευνώ ερευνώμαι ερεύγομαι ερημοδικώ ερημώνομαι ερημώνω ερματίζω ερμηνεύω
 ερυθριάζω ερυθριώ ερωτεύομαι ερωτοτροπώ ερωτώ ερώμαι εσθίω εσοδεύω εστιάζω
 εσωτερικεύω ετάζω ετεροχρονίζω ετοιμάζομαι ετοιμάζω ετυμολογώ ευαγγελίζομαι
 ευαισθητοποιώ ευαρεστούμαι ευαρεστώ ευγνωμονώ ευδαιμονίζω ευδαιμονώ ευδιάζω
 ευδοκώ ευελπιστώ ευεργετώ ευημερώ ευθετίζω ευθετώ ευθυγραμμίζω ευθυμογραφώ
 ευθυμώ ευθύνομαι ευκαιρώ ευκολύνω ευλαβούμαι ευλογούμαι ευλογώ ευνομούμαι
 ευνοώ ευοδούμαι ευοδώνομαι ευπορώ ευπραγώ ευπρεπίζω ευρίσκομαι ευρίσκω ευρωτιώ
 ευσπλαγχνίζομαι ευσπλαχνίζομαι ευσταθώ ευστοχώ ευτελίζω ευτρεπίζω ευτυχίζω
 ευφραίνομαι ευφραίνω ευφυολογώ ευχαριστιέμαι ευχαριστούμαι ευχαριστώ ευωδιάζω
 ευωχούμαι εφάπτομαι εφέλκω εφαρμόζομαι εφαρμόζω εφελκύω εφεσιβάλλω εφευρίσκω
 εφησυχάζω εφιδρώνω εφιστώ εφοδιάζομαι εφοδιάζω εφοπλίζω εφορεύω εφορμώ
 εχθρεύομαι εχτρεύομαι εύχομαι ζάφτω ζέχνω ζέω ζαβλακώνω ζαβώνω ζαλίζομαι
 ζαλικώνομαι ζαλικώνω ζαλώνομαι ζαλώνω ζαρίζω ζαρώνω ζαχαριάζω ζαχαρώνω
 ζελατινοποιώ ζεματίζω ζεματώ ζεσταίνομαι ζεσταίνω ζεστοκοπιέμαι ζευγαρίζω
 ζεύγω ζεύω ζηλεύω ζηλοτυπώ ζηλοφθονώ ζηλώ ζημιώνομαι ζημιώνω ζητιανεύω
 ζητωκραυγάζω ζητώ ζητῶ ζογκλάρω ζορίζομαι ζορίζω ζουζουνίζω ζουλίζω ζουλεύω
 ζουμάρω ζουπίζω ζουπώ ζουριάζω ζουρλαίνω ζοχαδιάζω ζυγίζω ζυγιάζω ζυγοσταθμίζω
 ζυμώνω ζω ζωγραφίζομαι ζωγραφίζω ζωγραφώ ζωηρεύω ζωντανεύω ζωογονώ ζωοποιώ
 ζώνω ηγεμονεύω ηγουμενεύω ηγούμαι ηδονίζομαι ηδονίζω ηδύνομαι ηθικολογώ
 ηθογραφώ ηθολογώ ηλεκτρίζομαι ηλεκτρίζω ηλεκτροδοτώ ηλεκτρολύω ηλεκτροφορώ
 ηλιάζω ηλικιώνομαι ημερεύω ημερώνω ημιταυτοχρονίζομαι ημπορώ ηνιοχώ ηξεύρω
 ηρεμώ ηρωοοποιούμαι ηρωοποιώ ησυχάζω ηττώμαι ηχοβολίζω ηχογραφώ ηχολογώ ηχώ
 θάβω θάλλω θάλπω θάπτω θάφτω θέλγω θέλω θέτω θέω θίγομαι θίγω θαλασσοδέρνομαι
 θαλασσοκρατώ θαλασσομαχώ θαλασσοπνίγομαι θαλασσοποιώ θαλασσώνω θαμάζω θαμβώνω
 θαμποφέγγω θαμπώνω θανατώνω θαρρεύω θαρρώ θαυμάζω θαυματουργώ θεατρίζω
 θεληματίζω θελιάζω θεμελιώνω θεοδρομώ θεολογώ θεομαχώ θεοποιούμαι θεοποιώ
 θερίζομαι θερίζω θεραπεύομαι θεραπεύω θεριακώνομαι θεριεύω θερμαίνω θερμομετρώ
 θεσιθηρώ θεσμίζω θεσμοθετώ θεσπίζω θεωρητικολογώ θεωρητικοποιώ θεωρούμαι θεωρώ
 θηκαρώνω θηκιάζω θηλάζω θηλιάζω θηλυκώνω θημωνιάζω θηρεύω θησαυρίζομαι
 θητεύω θλίβομαι θλίβω θνήσκω θολώνω θορυβούμαι θορυβώ θρέφω θρασεύω θρασομανώ
 θραύω θρηνολογώ θρηνούμαι θρηνωδώ θρηνώ θρησκεύομαι θριαμβεύω θριαμβολογώ
 θρομβούμαι θρομβώνω θρονιάζομαι θρονιάζω θροώ θρυλώ θρυμματίζομαι θρυμματίζω
 θρύβω θρύπτω θυμάμαι θυμίζω θυματοποιώ θυμιάζω θυμιατίζω θυμούμαι θυμώνω
 θυσιάζομαι θυσιάζω θωπεύω θωράω θωρακίζω θωρώ θύω ιαίνω ιατρεύω ιδανικεύω
 ιδιάζω ιδιοκατοικώ ιδιοποιούμαι ιδιωτεύω ιδιωτικοποιούμαι ιδιωτικοποιώ
 ιδρυματοποιούμαι ιδρυματοποιώ ιδρύω ιδρώνω ιεραρχώ ιερατεύω ιερολογώ ιεροσυλώ
 ιζάνω ιθύνω ικανοποιούμαι ικανοποιώ ικετεύω ιλαρύνω ιντριγκάρω ιονίζω ιππεύω
 ισάζω ισιάζω ισιώνω ισκιώνω ισοβαθμώ ισοδυναμώ ισοζυγίζω ισοζυγιάζω ισοζυγώ
 ισοπεδώνω ισορροπώ ισοσκελίζω ισοσταθμίζω ισοσταθμώ ισοφαρίζω ισοψηφώ ισούμαι
 ιστολογώ ιστορίζω ιστορώ ισχάζω ισχναίνω ισχνεύω ισχυρίζομαι ισχυροποιούμαι
 ισχύω ισώνω ιχνεύω ιχνηλατώ ιχνογραφώ κάβω κάθημαι κάθομαι κάμνω κάμπτω κάνω
 κήδομαι καίγομαι καίγω καίω καβαλικεύω καβαλώ καβαντζάρω καβατζάρω καβγαδίζω
 καβουρντίζω καγχάζω καδράρω καδρονιάζω καζανιάζω καζαντίζω καθάπτω καθέλκω
 καθίσταμαι καθαγιάζομαι καθαγιάζω καθαγνίζω καθαιμάσσω καθαιρώ καθαρίζομαι
 καθαρεύω καθαρογράφω καθαρογραφώ καθελκύω καθετηριάζω καθετοποιώ καθεύδω
 καθηλώνω καθησυχάζω καθιδρύω καθιερώνομαι καθιερώνω καθιζάνω καθικετεύω
 καθοδηγώ καθολικεύω καθομολογώ καθορίζω καθορώ καθοσιώνω καθρεπτίζω
 καθρεφτίζω καθυβρίζω καθυγραίνω καθυποτάζω καθυποτάσσω καθυποχρεώ καθυποχρεώνω
 καινοτομώ καιροσκοπώ καιροφυλακτώ καιροφυλαχτώ κακίζω κακαδιάζω κακαρίζω
 κακαφορούμαι κακιώνω κακοβάζω κακοβάνω κακογαμώ κακογεννώ κακογερνώ
 κακογράφω κακογραφώ κακοδαιμονώ κακοδιοικούμαι κακοδιοικώ κακοδοξώ κακοζωίζω
 κακοθανατίζω κακοκαρδίζω κακοκοιμάμαι κακολογιάζω κακολογώ κακομαθαίνω
 κακομεταχειρίζομαι κακομιλώ κακομοιριάζομαι κακομοιριάζω κακοπέφτω κακοπαίρνω
 κακοπαθώ κακοπαντρεύομαι κακοπαντρεύω κακοπερνώ κακοπληρώνω κακοποιούμαι
 κακοσαρκώνω κακοστομαχιάζω κακοσυνεύω κακοσυνηθίζω κακοσυσταίνω κακοτυχίζω
 κακουργώ κακοφέρνομαι κακοφαίνεται κακοφορμίζω κακοχρονίζω κακοχωνεύω
 κακοψήνω κακό χρόνο να 'χεις καλάρω καλένω καλαΐζω καλαθιάζω καλαθώνω καλακούω
 καλαμπουρίζω καλαρέσω καλαφατίζω καλημερίζομαι καλημερίζω καληνυχτίζω
 καλησπερίζω καλιγώνω καλιμπράρω καλλιγράφω καλλιγραφώ καλλιεργώ καλλιλογώ
 καλλουργώ καλλωπίζω καλλύνω καλλύνω καλμάρω καλμώνω καλοαρέσω καλοβαστώ
 καλοβράζω καλογεννώ καλογερεύω καλογυρεύω καλοδέχομαι καλοεξετάζω καλοζυγίζω
 καλοζώ καλοθανατίζω καλοθυμάμαι καλοθυμούμαι καλοκάθομαι καλοκαιρεύει
 καλοκαιριάζει καλοκαιριάζω καλοκαρδίζω καλοκοιμάμαι καλοκοιτάζω καλολέω
 καλομαθαίνω καλομελετώ καλομεταχειρίζομαι καλομετρώ καλομιλώ καλοναρχώ
 καλοπέφτω καλοπαντρεύομαι καλοπαντρεύω καλοπερνώ καλοπιάνω καλοπληρώνω
 καλοσκαμνίζω καλοστρώνομαι καλοστρώνω καλοσυνεύω καλοσυνηθίζω καλοταΐζω
 καλοτυχίζω καλουμάρω καλουπώνω καλοφαίνομαι καλοχρονίζω καλοχωνεύω καλοψήνομαι
 καλοψυχίζω καλούμαι καλπάζω καλπονοθεύω καλυτερεύω καλωδιώνω καλωσορίζω
 καλύπτω καλώ καλῶ καμακίζω καμακιάζω καμακώνω καμαρώνομαι καμαρώνω καματεύω
 καμινιάζω καμμύζω καμμύω καμνώ καμουφλάρω καμπανίζω καμπουριάζω καμπυλώνω
 κανακίζω κανακεύω κανονίζομαι κανονίζω κανοναρχώ κανονιοβολώ καπακώνω καπαρώνω
 καπελώνω καπηλεύομαι καπιστρώνω καπιτονάρω καπλαντίζω καπνίζω καραβοτσακίζομαι
 καραμελιάζω καραμελώνομαι καραμελώνω καρατάρω καρατομώ καραφλιάζω καρβουνιάζω
 καρδαμώνω καρδιοχτυπώ καρικώνω καρκινοβατώ καρναγιάρω καρπίζω καρπαζώνω
 καρπολογώ καρποφορώ καρπούμαι καρπώνομαι καρτελοποιώ καρτερεύω καρτερώ
 καρυκεύω καρφιτσώνομαι καρφιτσώνω καρφώνομαι καρφώνω καρώνω κασελιάζω
 κασσιτερώνομαι κασσιτερώνω κατάγομαι κατάγω κατάκειμαι κατάσχομαι κατάσχω
 κατέχομαι κατέχω καταβάλλομαι καταβάλλω καταβαίνω καταβαραθρώνω καταβιβάζω
 καταβοδώνω καταβολίζω καταβολεύω καταβολιάζω καταβρέχομαι καταβρέχω
 καταβροχθίζω καταβυθίζω καταγίνομαι καταγγέλλω καταγελώ καταγιγνώσκω
 καταγοητεύω καταγράφομαι καταγράφω καταδέχομαι καταδίδω καταδίνω καταδαμάζω
 καταδεικνύω καταδημαγωγώ καταδικάζω καταδιώκω καταδολιεύομαι καταδυναστεύω
 καταζητούμαι καταζητώ καταθέτω καταθλίβω καταθορυβώ κατακάθημαι κατακάθομαι
 κατακαθίζω κατακεραυνώνω κατακερματίζομαι κατακερματίζω κατακιτρινίζω
 κατακλίνομαι κατακλείνω κατακλύζομαι κατακλύζω κατακοκκινίζω κατακουράζω
 κατακρίνομαι κατακρίνω κατακρατώ κατακραυγάζω κατακρεουργώ κατακρημνίζω
 κατακτώ κατακτώμαι κατακυριεύω κατακυρώνω κατακόβω κατακόπτω καταλάμπω
 καταλήγω καταλαβαίνω καταλαγιάζω καταλαλώ καταλαμβάνω καταλασπώνω καταλείπω
 καταληστεύω καταλογίζω καταλογογραφώ καταλυπώ καταλύω καταλώ καταμαρτυρώ
 καταμαυρίζω καταμερίζω καταμετρώ καταμηνύω καταμοσχεύω κατανέμω καταναγκάζω
 καταναλώνομαι καταναλώνω καταναυμαχώ κατανεύω κατανικώ κατανοώ καταντρέπομαι
 καταντροπιάζω καταντώ καταξεραίνω καταξεσκίζω καταξεσχίζω καταξηραίνω
 καταξοδεύομαι καταξοδεύω καταξοδιάζω καταπέμπω καταπέφτω καταπίνω καταπίπτω
 καταπείθω καταπιάνομαι καταπιέζω καταπικραίνω καταπλέω καταπλήσσω καταπλήττω
 καταπληγώνω καταπλημμυρίζω καταπλημμυρώ καταπλύνομαι καταπνίγω καταπολεμάω
 καταπολεμώ καταπολεμώμαι καταπονούμαι καταποντίζω καταπονώ καταπραΰνομαι
 καταπτοώ καταπτύω καταργώ καταριέμαι καταριθμώ καταρρέω καταρρίπτω
 καταρρακώνω καταρροφώ καταρτίζω καταρώμαι κατασβήνω κατασημαίνω κατασιγάζω
 κατασκευάζομαι κατασκευάζω κατασκηνώνομαι κατασκηνώνω κατασκιάζω κατασκονίζω
 κατασκορπίζω κατασκοτώνομαι κατασκοτώνω κατασπαράζω κατασπαράσσω κατασπαταλώ
 καταστέλλω καταστίζω κατασταίνω κατασταλάζω καταστενοχωρώ καταστερίζω
 καταστρέφω καταστρατηγώ καταστροφολογώ καταστρώνω κατασυκοφαντώ κατασυντρίβω
 κατασφαγιάζω κατασχάζω κατασωτεύω κατατάσσομαι κατατάσσω κατατέμνω κατατίθεμαι
 καταταράζω καταταράσσω κατατείνω κατατεμαχίζω κατατοπίζομαι κατατοπίζω
 κατατρίβομαι κατατραυματίζω κατατρομάζω κατατροπώνω κατατρυπώ κατατρύχω
 κατατρώω κατατσακίζω κατατυραννώ καταυγάζω καταυλίζομαι καταφέρνω καταφέρομαι
 καταφαίνομαι καταφεύγω καταφθάνω καταφιλῶ καταφρονώ καταφτάνω καταχέζω
 καταχειροκροτώ καταχερίζω καταχεριάζω καταχνιάζει καταχρεώνομαι καταχρώμαι
 καταχωνιάζω καταχωρίζω καταχωρώ καταχώνομαι καταχώνω καταψηφίζω καταψύχω
 καταϋποχρεώνω κατεβάζω κατεβαίνω κατεδαφίζω κατειρωνεύομαι κατενθουσιάζω
 κατεργάζομαι κατερειπώνω κατευθύνομαι κατευθύνω κατευνάζω κατευοδώνω
 κατηγοριοποιούμαι κατηγοριοποιώ κατηγορούμαι κατηγορώ κατηφορίζω κατηχώ
 κατισχύω κατοικίζω κατοικοεδρεύω κατοικώ κατολισθαίνω κατολοφύρομαι κατονομάζω
 κατοπτρίζω κατορθώνω κατοστίζω κατουριέμαι κατουρώ κατοχυρώνω κατρακυλάω
 κατραμώνω κατραπακιάζω κατσαβιδώνω κατσαδιάζω κατσαρώνω κατσιάζω κατσικώνομαι
 κατσουφιάζω καυκιέμαι καυλαντίζω καυλοκοιτάω καυλώνω καυτηριάζω καυχησιολογώ
 καφασώνω καψαλίζω καψώνω κβαντίζω κείμαι κείρομαι κείρω κείτομαι κελαδώ
 κελαηδώ κελαρύζω κελαϊδάω κελαϊδώ κελεύω κεντράρω κεντρίζω κεντρώνω κεντώ
 κεραμιδώνω κερατώνω κεραυνοβολώ κεραυνώνω κερδίζομαι κερδίζω κερδαίνω κερδεύω
 κερματίζω κερνάω κερνώ κερώνω κεφαλαιοποιώ κεφαλαλγώ κεφαλοπονώ κηδεμονεύω
 κηκίω κηλιδώνω κηπεύω κηρύσσομαι κηρύσσω κηρύττομαι κηρύττω κιαλάρω κιβδηλεύω
 κιθαρίζω κιθαρωδώ κιμαδιάζω κινδυνεύω κινδυνολογώ κινηματογραφούμαι
 κινητοποιούμαι κινητοποιώ κινητροδοτούμαι κινητροδοτώ κινούμαι κιντυνεύω κινώ
 κιτρινίζω κλάνω κλέβω κλέπτω κλέπτω κλέφτω κλίνω κλαίγομαι κλαίγω κλαίω
 κλαδεύω κλαδώνω κλαουρίζω κλαρώνω κλασαυχενίζομαι κλασικίζω κλατάρω
 κλαψουρίζω κλείνω κλειδαμπαρώνω κλειδαριθμώ κλειδομανταλώνω κλειδώνομαι
 κλειώ κληροδοτώ κληρονομούμαι κληρονομώ κληρώνω κλητεύομαι κλητεύω κλικάρω
 κλιμακώνομαι κλιμακώνω κλονίζομαι κλονίζω κλοτσάω κλοτσώ κλουβιάζω κλουβιαίνω
 κλωθογυρίζω κλωνοποιώ κλωσώ κλωτσώ κλώζω κλώθω κνίζω κοάζω κοίτομαι κογιονάρω
 κοιλαίνω κοιλοπονώ κοιμάμαι κοιμίζω κοιμούμαι κοινολογώ κοινοποιούμαι
 κοινωνικοποιώ κοινωνώ κοιτάζομαι κοιτάζω κοιτώ κοκαλιάζω κοκαλώνω κοκκαλώνω
 κοκκοποιώ κοκορίζω κοκορεύομαι κολάζω κολακεύω κολαντρίζω κολατσίζω κολαφίζω
 κολεκτιβοποιώ κολεχτιβοποιώ κολλάρω κολλάω κολλαρίζω κολλώ κολοβώνω κολυμπάω
 κολώ κομίζω κομματίζομαι κομματιάζω κομματοσκυλιάζω κομουνίζω κομπάζω κομπιάζω
 κομπλιμεντάρω κομποδένω κομπορρημονώ κομπώνω κομψεύομαι κονεύω κονιοποιώ
 κονιορτοποιώ κονομάω κονσερβοποιώ κονταίνω κοντανασαίνω κονταροχτυπιέμαι
 κοντοζυγώνω κοντοστέκομαι κοντοστέκω κοντράρω κοντραστάρω κοντροκρατώ
 κοπάζω κοπανίζω κοπανώ κοπιάζω κοπιάρω κοπιώ κοπρίζω κοπροσκυλιάζω κοπροσκυλώ
 κορακιάζω κορδακίζομαι κορδακίζω κορδελιάζω κορδώνομαι κορδώνω κορεννύομαι
 κορεύω κοριάζω κορνάρω κορνιζάρω κορνιζώνω κοροϊδεύω κορτάρω κορυβαντιώ
 κορυφώνομαι κορυφώνω κορφολογώ κορώνω κοσίζω κοσεύω κοσκινίζω κοσμώ κοστάρω
 κοστολογώ κοτάω κοτσάρω κοτώ κουβαλάω κουβαλώ κουβαριάζω κουβεντιάζω κουβιαίνω
 κουδουνίζω κουζουλαίνω κουκουλώνομαι κουκουλώνω κουλάρω κουλαίνω κουλαντρίζω
 κουλουριάζω κουμαντάρω κουμπαριάζω κουμπώνω κουνάω κουνιέμαι κουντώ κουνώ
 κουράζω κουράρω κουρδίζομαι κουρδίζω κουρελιάζω κουρεύομαι κουρεύω
 κουρνιάζω κουρντίζω κουρσεύω κουρταλώ κουτιαίνω κουτουλίζω κουτουλώ κουτουπώνω
 κουτρουβαλώ κουτρώ κουτσαίνω κουτσοκαταφέρνω κουτσομπολεύω κουτσομπολιάζω
 κουτσοπερπατώ κουτσουλίζω κουτσουλώ κουτσουρεύω κουφίζω κουφαίνω κουφοβράζω
 κοφινιάζω κοφώνω κοχλάζω κοχλιώνω κοψομεσιάζομαι κοψομεσιάζω κοψοχολιάζω κράζω
 κρέμομαι κρέμουμαι κρένω κρίνομαι κρίνω κραίνω κραδαίνω κρασάρω κρασοπίνω
 κραταιώνω κρατιέμαι κρατικοποιούμαι κρατικοποιώ κρατούμαι κρατύνω κρατώ
 κρεβατώνομαι κρεβατώνω κρεμάω κρεμιέμαι κρεμνώ κρεμώ κρεουργώ κρεοφαγώ κρεπάρω
 κρηπιδώνω κρησαρίζω κριθαρίζω κριματίζομαι κριματίζω κριτικάρω κριτσανίζω
 κροταλίζω κροτώ κρουσταλλιάζω κρουστοϋφαίνω κρούω κρυολογώ κρυπτογραφώ
 κρυσταλλώνω κρυφακούω κρυφογελώ κρυφοκαίω κρυφοκαμαρώνω κρυφοκοιτάζομαι
 κρυφοκοιτάω κρυφοκοιτιέμαι κρυφοκοιτώ κρυφομιλώ κρυφοσμίγω κρυώνω κρύβομαι
 κρύπτω κρώζω κτίζω κτενίζω κτερίζω κτηνοβατώ κτυπάω κτυπιέμαι κτυπώ κτώμαι
 κυβερνάω κυβερνιέμαι κυβερνώ κυβερνώμαι κυβεύω κυκλοφορώ κυκλώνω κυλάω κυλίω
 κυλινδρώνω κυλινδώ κυλώ κυμαίνομαι κυματίζω κυμβαλίζω κυνηγώ κυοφορώ κυριαρχώ
 κυριεύω κυριολεκτώ κυριολεχτώ κυρτώνω κυρώ κυρώνω κωδικοποιώ κωδωνίζω
 κωκύω κωλοβαράω κωλοβαρώ κωλοκάθομαι κωλοφιλώ κωλυσιεργώ κωλύομαι κωλύω κωλώνω
 κωπηλατώ κωφεύω κόβομαι κόβω κόπτομαι κόπτω κόφτω κύκλω κύπτω κύρω λάμνω λάμπω
 λέγω λέω λήγω λαβαίνω λαβατώνω λαβώνω λαγαρίζω λαγγεύω λαγιάζω λαγνοκοιτώ
 λαγοκοιμάμαι λαγχάνω λαδομπογιαντίζω λαδομπογιατίζω λαδώνω λαθεύω λαθρακιάζω
 λαθροταξιδεύω λακίζω λακτίζω λακωνίζω λακώ λαλώ λαμβάνομαι λαμβάνω λαμινάρω
 λαμπικάρω λαμποκοπάω λαμποκοπώ λαμπρύνω λαμπυρίζω λαναρίζω λανθάνω λανσάρω
 λαπαδιάζω λαρυγγίζω λασκάρω λασπιάζω λασποκυλιέμαι λασπολογώ λασπώνω λατινίζω
 λατρεύω λαφιάζω λαφυραγωγώ λαχαίνω λαχανιάζω λαχταρίζω λαχταρώ λαϊκίζω λείπω
 λεβάρω λεηλατώ λειαίνω λειτουργιέμαι λειτουργούμαι λειτουργώ λειχηνιάζω
 λειώνω λεκιάζω λεξιθηρώ λεξικογραφώ λεοντοποιώ λεπταίνω λεπτολογώ λεπτύνω
 λερώνω λεσβιάζω λευκάζω λευκαίνω λευκοφορώ λευτερώνω λευχειμονώ λημεριάζω
 λημματολογώ λησμονάω λησμονώ ληστεύω ληστοκρατούμαι λιάζομαι λιάζω λιανίζω
 λιανοκόβω λιβανίζω λιβελογραφώ λιγδιάζω λιγδώνω λιγνεύω λιγοθυμώ λιγοστεύω
 λιγοψυχώ λιγώνομαι λιγώνω λιθοβολώ λιθογραφώ λιθοδομώ λιθολογώ λιθοστρώνω
 λικνίζω λιμάζω λιμάρω λιμνάζω λιμοκτονώ λιμπίζομαι λιμώττω λιντσάρω λιοτρίβω
 λιποθυμάω λιποθυμώ λιποτακτώ λιποταχτώ λιποψυχώ λιτανεύω λιχνίζω λιχνεύομαι
 λιώνω λογίζομαι λογαριάζομαι λογαριάζω λογγώνω λογιάζομαι λογιάζω λογιέμαι
 λογικεύω λογιοτατίζω λογογραφώ λογοδοτώ λογοκλέπτω λογοκλοπώ λογοκρίνω
 λογοπαικτώ λογοφέρνω λογυρνάω λογχίζω λογχεύω λοιδορώ λοξεύω λοξοδρομώ
 λουλουδίζω λουλουδιάζω λουπάρω λουσάρω λουσαρίζω λουστράρω λουφάζω λουφάρω
 λούζω λούω λυγίζω λυγιέμαι λυγώ λυμαίνομαι λυντσάρω λυπάμαι λυπούμαι λυποῦμαι
 λυσσάζω λυσσιάζω λυσσομανώ λυσσώ λυτρώνομαι λυτρώνω λωβιάζω λωλαίνω λύνομαι
 λύω μάμνω μάχομαι μέλει μέλλω μέλπω μέμφομαι μένω μίσγω μαίνομαι μαγαρίζω
 μαγγώνομαι μαγγώνω μαγειρεύομαι μαγειρεύω μαγεύομαι μαγεύω μαγκεύω μαγκώνω
 μαγνητίζω μαγνητοσκοπούμαι μαγνητοσκοπούμαι μαγνητοσκοπώ μαγνητοφωνώ μαδάω
 μαζεύομαι μαζεύω μαζώνω μαζώχνω μαθαίνω μαθεύομαι μαθητεύω μαθητιώ μαιεύομαι
 μακαρίζω μακαρονίζω μακελεύω μακιγιάρομαι μακιγιάρω μακραίνω μακρηγορώ
 μακροθυμώ μακρολογώ μακρύνω μαλάζω μαλάσσω μαλαγρώνω μαλακίζομαι μαλακώνομαι
 μαλαματοκαπνίζομαι μαλαματοκαπνίζω μαλαματώνω μαλαμοκαπνίζω μαλθακώνω μαλλιάζω
 μαλώνω μανίζω μανατζάρω μανθάνω μανιάζω μανικώνω μανιπουλάρω μανιώνω
 μαντάρω μανταλώνω μαντατεύω μαντεύω μαντιλοδένομαι μαντρίζω μαντρώνω
 μαραίνομαι μαραίνω μαραγκιάζω μαραζιάζω μαραζώνω μαργώνω μαρινάρω μαρκάρω
 μαρκαλίζω μαρκαλώ μαρμαίρω μαρμαρώνω μαρσάρω μαρτυράω μαρτυρώ μασάω μασιέμαι
 μασουλάω μασουλίζω μασουλιέμαι μασουλώ μασουρίζω μαστίζω μαστιγώνω μαστιχώνω
 μαστουριάζω μαστουρώνω μασώ μασώμαι ματίζω ματαέρχομαι ματαβλέπω ματαγυρίζω
 ματαιοδοξώ ματαιολογώ ματαιοπονώ ματαιοφρονώ ματαιώνω ματιάζω ματοκυλίζω
 ματώνω μαυλάω μαυλίζω μαυρίζω μαυρολογώ μαυροφορώ μαχαιρώνομαι μαχαιρώνω
 μαϊνάρω μαϊστραλίζω μεγαλαυχώ μεγαληγορώ μεγαλοπιάνομαι μεγαλοποιούμαι
 μεγαλοπραγμονώ μεγαλορρημονώ μεγαλουργώ μεγαλοφέρνω μεγαλοφρονώ μεγαλύνω
 μεγαλώνω μεγεθύνω μεγιστοποιούμαι μεγιστοποιώ μεθάω μεθερμηνεύω μεθοδεύω
 μεθορμίζω μεθύσκομαι μεθύσκω μεθύω μεθώ μειγνύω μειδιώ μειοδοτώ μειονεκτώ
 μειοψηφώ μειώνω μελαίνω μελαγχολώ μελανειμονώ μελανηφορώ μελανιάζω μελανώνω
 μελετώ μελετώμαι μελοδραματοποιώ μελοποιώ μελωδώ μελώνω μεμψιμοιρώ μερίζω
 μερεμετίζω μερεύω μεριάζω μερικεύω μεριμνώ μεροληπτώ μερώνω
 μεσημεριάζει μεσημεριάζω μεσιτεύω μεσοκόβω μεσολαβώ μεσουρανώ μεστώνω μεσώ
 μετέρχομαι μετέχω μεταβάλλομαι μεταβάλλω μεταβαίνω μεταβαπτίζω μεταβιβάζω
 μεταβολίζω μεταγγίζομαι μεταγγίζω μεταγλωττίζομαι μεταγλωττίζω μεταγράφομαι
 μεταγραμματίζω μεταγυρίζω μεταδίδομαι μεταδίδω μεταδίνω μεταδιεγείρω μεταθέτω
 μετακινούμαι μετακινώ μετακομίζω μεταλαβαίνω μεταλαμβάνω μεταλαμπαδεύω
 μεταλλάσσομαι μεταλλάσσω μεταλλεύω μεταμελούμαι μεταμισθώνω μεταμορφώνομαι
 μεταμοσχεύομαι μεταμοσχεύω μεταμφίεση μεταμφιέζομαι μεταμφιέζω μεταναστεύω
 μετανοώ μεταπίπτω μεταπείθομαι μεταπείθω μεταπηδώ μεταπλάθω μεταπλάσσω
 μεταποιώ μεταπουλάω μεταπουλώ μεταπωλούμαι μεταπωλώ μεταραιώνω μεταρρυθμίζομαι
 μεταρσιώνομαι μεταρσιώνω μετασκευάζομαι μετασκευάζω μετασταθμεύω
 μεταστοιχειώνω μεταστρέφομαι μεταστρέφω μεταστρατοπεδεύω μετασχηματίζομαι
 μετατάσσομαι μετατάσσω μετατίθεμαι μετατοπίζομαι μετατοπίζω μετατρέπω
 μεταφέρνω μεταφέρομαι μεταφέρω μεταφορτώνω μεταφράζομαι μεταφράζω
 μεταφυτεύω μεταχειρίζομαι μεταχρωματίζω μετεγγράφομαι μετεγγράφω
 μετεκπαιδεύω μετεμφυτεύομαι μετεμψυχώνομαι μετεμψυχώνω μετενσαρκώνομαι
 μετενσωματώνω μετεξελίσσομαι μετεπιβιβάζω μετεωρίζομαι μετεωρίζω μετοικίζω
 μετονομάζομαι μετονομάζω μετουσιώνω μετοχετεύω μετράω μετριάζομαι μετριάζω
 μετριοφρονώ μετρώ μεφιτίζω μηδίζω μηδενίζομαι μηδενίζω μηκύνω μηκώμαι μηλοβολώ
 μηνύομαι μηνύω μηνώ μηρυκάζω μηχανεύομαι μηχανογραφώ μηχανοποιώ
 μηχανοργανώνω μηχανορραφώ μηχανώμαι μιαίνομαι μιαίνω μικιάρω μικραίνω
 μικροδείχνω μικρολογώ μικροπαντρεύομαι μικροπαντρεύω μικροφέρνω μικρύνω μιλάω
 μιλώ μιμούμαι μινάρω μινυρίζω μιξάρω μισανοίγω μισεύω μισθοδοτώ μισθώνομαι
 μισοκοιμάμαι μισοτελειώνω μισούμαι μισώ μνέσκω μνημονεύομαι μνημονεύω
 μνηστεύομαι μνηστεύω μοιάζω μοιράζομαι μοιράζω μοιραίνω μοιρολογώ μοιχεύω
 μολέρνω μολεύομαι μολεύω μολογώ μολυβώνω μολύνομαι μολύνω μομιοποιώ μονάζω
 μονιάζω μονιμοποιούμαι μονιμοποιώ μονογράφομαι μονογράφω μονογραφώ μονοδρομώ
 μονολογώ μονομαχώ μονοπωλούμαι μονοπωλώ μοντάρω μοντερνίζω μονώνομαι μονώνω
 μορφοποιούμαι μορφοποιώ μορφοτυπώ μορφώνομαι μορφώνω μοσκοβολώ μοσκομυρίζω
 μοστράρω μοσχεύω μοσχοβολώ μοσχομυρίζω μοσχοπληρώνω μοσχοπουλιέμαι μοσχοπουλώ
 μουγγαίνω μουγκαίνομαι μουγκαίνω μουγκανίζω μουγκρίζω μουδιάζω μουζώνομαι
 μουκανίζω μουλαρώνω μουλιάζω μουλώνω μουλώχνω μουμιοποιούμαι μουμιοποιώ
 μουνουχίζω μουντάρω μουνταίνω μουντζαλώνομαι μουντζαλώνω μουντζουρώνομαι
 μουντζώνομαι μουντζώνω μουραίνω μουρλαίνομαι μουρλαίνω μουρμουράω μουρμουρίζω
 μουρτζουφλώ μουσκεύομαι μουσκεύω μουσκλιάζω μουσουργώ μουστώνω μουτεύω
 μουτρώνω μουφλουζεύω μουχλιάζω μουχρώνει μουχρώνω μοχθώ μοχλεύω μοχτώ μπάζω
 μπήγω μπήζω μπήχνω μπαίνω μπαγδαντίζω μπαγδατίζω μπαγιατίζω μπαγιατεύω
 μπαζώνω μπαινοβγαίνω μπακιρώνω μπαλαμουτιάζω μπαλαντζάρω μπαλσαμώνω μπαλωτάρω
 μπαλώνω μπαμπακιάζω μπαμπουλώνω μπανίζω μπανιάρομαι μπανιάρω μπανιαρίζω
 μπαρκάρω μπαρουτιάζω μπασταρδεύομαι μπασταρδεύω μπαστουρώνω μπατάρω μπατίρω
 μπατιρίζω μπατσίζω μπαφιάζω μπαϊλντίζω μπαϊλντώ μπεγλερίζω μπεγλερώ μπεζεράω
 μπεκρολογάω μπεκρολογώ μπεκροπίνω μπεκρουλιάζω μπεμπεκίζω μπερδεύομαι μπερδεύω
 μπιζάρω μπιμπικιάζω μπιμπιλώνω μπινεύω μπιρμπιλίζω μπιτίζω μπιφτεκώνω
 μπλέκω μπλαβίζω μπλανσάρω μπλαστρώνομαι μπλαστρώνω μπλοκάρω μπλοφάρω
 μπογιατίζομαι μπογιατίζω μποδίζω μπολεύω μπολιάζομαι μπολιάζω μπολικαίνω μπορώ
 μποσκάρω μποτζάρω μποτιλιάρω μποτσάρω μπουγαδιάζω μπουγελώνω μπουζουριάζω
 μπουκετάρω μπουκώνομαι μπουκώνω μπουμπουκιάζω μπουμπουνίζει μπουμπουνίζω
 μπουρδουκλώνομαι μπουρδουκλώνω μπουρινιάζω μπουσουλάω μπουσουλίζω μπουσουλώ
 μποχάρω μποϊκοτάρω μποϋκοτάρω μπρουμουτίζω μυγιάζομαι μυζώ μυθιστοριογραφώ
 μυθογραφώ μυθολογώ μυθοποιούμαι μυθοποιώ μυκτηρίζω μυκώμαι μυξιάζω μυξοκλαίω
 μυρίζομαι μυρίζω μυριαναστενάζω μυρμηγκιάζω μυρμηκιώ μυρώνω μυσταγωγώ μυστρίζω
 μυωπάζω μυώ μωλωπίζομαι μωλωπίζω μωραίνομαι μωραίνω μωρολογώ μωρουδίζω μύρομαι
 νέμομαι νέμω νέω νίβομαι νίβω νίπτω νίφτω νανουρίζομαι νανουρίζω ναρκισσεύομαι
 ναρκοθετώ ναρκώνομαι ναρκώνω ναυαγώ ναυλοχώ ναυλώνομαι ναυλώνω ναυμαχώ
 ναυπηγοκατασκευαστικός ναυπηγούμαι ναυπηγώ ναυτίλλομαι ναυτολογώ νεάζω
 νεανίζω νεκατσιώ νεκρανασταίνομαι νεκρανασταίνω νεκροστολίζω νεκροφιλώ
 νεκρώνω νεοσσεύω νεροβράζω νερουλιάζω νερώνω νετάρω νευριάζω νεφελοβατώ
 νεωλκώ νεωτερίζω νεύω νηνεμώ νηολογώ νηπιάζω νηπιοβαπτίζω νηστεύω νιαουρίζω
 νικιέμαι νικώ νικῶ νιτροποιώ νιώθω νιώνω νογάω νογώ νοηματοδοτώ νοθεύομαι
 νοιάζει νοιάζομαι νοικιάζομαι νοικιάζω νοικοκερεύω νοικοκυρεύομαι νοικοκυρεύω
 νομίζω νομαρχώ νοματίζω νομιμοποιούμαι νομιμοποιώ νομισματοποιώ νομοθετούμαι
 νοούμαι νοσηλεύομαι νοσηλεύω νοσταλγώ νοστιμίζω νοστιμεύομαι νοστιμεύω
 νοσώ νοτίζω νουθετώ νουνίζω νοώ νταβραντίζω νταγιαντίζω νταγιαντώ ντακέρνω
 νταντεύω νταραβερίζομαι ντελαλώ ντελαπάρω ντεμπουτάρω ντεραπάρω ντερλικώνω
 ντοπάρω ντουμανιάζω ντουμπλάρω ντουφεκίζομαι ντουφεκίζω ντουχιουντίζω
 ντρεσάρω ντροπιάζομαι ντροπιάζω ντύνομαι ντύνω ντώνω νυγματίζω νυκτερεύω
 νυμφεύομαι νυμφεύω νυμφοστολίζω νυστάζω νυφοστολίζω νυχιάζω νυχτερεύω
 νυχτοπερπατώ νυχτώνει νυχτώνομαι νυχτώνω νωχελεύω ξέρω ξέω ξαίνω ξαγγρίζω
 ξαγκιστρώνομαι ξαγκιστρώνω ξαγναντεύω ξαγορεύω ξαγρυπνώ ξαδιαντροπεύομαι
 ξαλέθω ξαλαφρώνω ξαλεγράρω ξαλλάζω ξαλμυρίζω ξαμολάω ξαμολιέμαι ξαμολώ ξαμώνω
 ξανάρχομαι ξανάφτω ξαναβάζω ξαναβάφω ξαναβγάζω ξαναβλέπω ξαναβράζω ξαναβρίσκω
 ξαναγαπώ ξαναγεμίζω ξαναγεννιέμαι ξαναγεννιούμαι ξαναγράφω ξαναγυρίζω
 ξαναδίνω ξαναδείχνω ξαναδιαβάζω ξαναδοκιμάζω ξαναενώνω ξαναεφαρμόζω
 ξαναζωντανεύω ξαναθυμάμαι ξαναθυμίζω ξανακάνω ξανακαλώ ξανακερδίζω
 ξανακοιμάμαι ξανακούω ξανακτίζω ξανακτυπώ ξανακυκλοφορώ ξανακυλώ ξαναλέγω
 ξαναλογαριάζω ξαναμιλώ ξαναμοιράζω ξαναμπαίνω ξαναμωραίνομαι ξανανάβω
 ξανανιώνω ξανανταμώνω ξαναξεκινώ ξαναπέφτω ξαναπαίρνω ξαναπαντρεύομαι
 ξαναπιάνω ξαναπληρώνω ξαναρίχνω ξαναρχίζω ξαναρχινώ ξαναρωτώ ξανασαίνω
 ξανασπρώχνομαι ξαναστήνω ξαναστρώνω ξανατοποθετούμαι ξανατρέχω ξανατυπώνω
 ξαναφέρνω ξαναφαίνομαι ξαναφεύγω ξαναφορμάρω ξαναφορτώνω ξαναφορώ ξαναφουντώνω
 ξαναχρησιμοποιώ ξαναχτίζω ξαναχτυπώ ξαναϋιοθετώ ξανεμίζω ξανθίζω ξανθαίνω
 ξανοίγω ξανταίνω ξαντιμεύω ξαπλάρω ξαπλώνομαι ξαπλώνω ξαπολνώ ξαπολώ
 ξαποστέλνω ξαποσταίνω ξαραχνιάζω ξαργώ ξαρματώνω ξαρμυρίζω ξαρραβωνιάζω
 ξαστερώνω ξαστοχώ ξαφνίζω ξαφνιάζομαι ξαφνιάζω ξαφρίζω ξεαποφασίζω ξεβάφω
 ξεβγάζομαι ξεβγάζω ξεβγάνω ξεβγαίνω ξεβιδώνω ξεβιράρω ξεβλασταρώνω ξεβλαστώνω
 ξεβουλώνω ξεβουτυρώνω ξεβράζω ξεβρακώνω ξεβρομίζω ξεγίνομαι ξεγαντζώνω
 ξεγελιέμαι ξεγελώ ξεγεννώ ξεγιβεντίζω ξεγλιστρώ ξεγνοιάζω ξεγοφιάζω ξεγράφω
 ξεγυμνώνω ξεγυρίζω ξεδένω ξεδίνω ξεδιακρίνω ξεδιαλέγω ξεδιαλύνω ξεδικιούμαι
 ξεδιψώ ξεδολώνω ξεδοντιάζομαι ξεδοντιάζω ξεζαλίζομαι ξεζαλίζω ξεζεύω ξεζουμάρω
 ξεζώνω ξεθάβω ξεθάφτω ξεθαμπώνω ξεθαρρεύω ξεθεμελιώνω ξεθεώνω ξεθηκαρώνω
 ξεθολώνω ξεθυμαίνω ξεθυμώνω ξεκάνω ξεκίνα ξεκαβαλικεύω ξεκαθαρίζω ξεκακιώνω
 ξεκαλουπώνω ξεκαλτσώνω ξεκαμπίζω ξεκαπακώνω ξεκαπελώνω ξεκαπιστρώνω ξεκαπνίζω
 ξεκαρφιτσώνω ξεκαρφώνω ξεκατινιάζω ξεκινάω ξεκινώ ξεκλέβω ξεκλειδώνομαι
 ξεκληρίζομαι ξεκληρίζω ξεκλωσώ ξεκοιλιάζομαι ξεκοιλιάζω ξεκοκαλίζομαι
 ξεκολλώ ξεκουμπίζομαι ξεκουμπώνομαι ξεκουμπώνω ξεκουράζομαι ξεκουράζω
 ξεκουρντίζω ξεκουτιαίνω ξεκουφαίνω ξεκρίνω ξεκρεμώ ξεκωλώνω ξεκόβω ξεκόφτω
 ξελαγαρίζω ξελαιμιάζομαι ξελαιμιάζω ξελακκώνω ξελαμπικάρω ξελαρυγγίζομαι
 ξελασκάρω ξελασπώνω ξελαφάσω ξελαφρώνω ξελειτουργώ ξελεπίζω ξελεπιάζω
 ξελιγώνω ξελογγώνω ξελογιάζω ξεμένω ξεμαγαρίζω ξεμαθαίνω ξεμακραίνω ξεμαλλιάζω
 ξεμασκαλίζω ξεμασκαρεύω ξεματιάζω ξεμαυλίζω ξεμεσημέριασμα ξεμεσημεριάζω
 ξεμοναχιάζω ξεμοντάρω ξεμουδιάζω ξεμουχλιάζω ξεμπαρκάρω ξεμπαστουρώνω
 ξεμπλέκω ξεμπλοκάρω ξεμπουκάρω ξεμπρατσώνομαι ξεμπροστιάζω ξεμυαλίζω
 ξεμυτίζω ξεμυτώ ξεμωραίνομαι ξεμωραίνω ξενίζω ξεναγούμαι ξεναγώ ξενερίζω
 ξενηλατώ ξενιτεύομαι ξενοδουλεύω ξενοιάζω ξενοικιάζω ξενοκοιμάμαι
 ξενοκοιτάζω ξενοκρατούμαι ξενοπλένω ξενοράβω ξεντερίζω ξεντύνομαι ξεντύνω
 ξενυχιάζω ξενυχτάω ξενυχτίζω ξενυχτώ ξεπέφτω ξεπαίρνομαι ξεπαγιάζω ξεπαγώνω
 ξεπαλουκώνω ξεπαραδιάζω ξεπαραλώ ξεπαρθενεύω ξεπαρθενιάζω ξεπαστρεύω
 ξεπατώνομαι ξεπατώνω ξεπεζεύω ξεπερνώ ξεπετάγομαι ξεπετιέμαι ξεπετώ ξεπηδώ
 ξεπλέκω ξεπλένομαι ξεπλένω ξεπλανεύω ξεπλατίζω ξεπληρώνω ξεπλύνω
 ξεποδαριάζω ξεπορτίζω ξεπουλώ ξεπουπουλιάζω ξεπροβάλλω ξεπροβαίνω ξεπροβαδίζω
 ξεπροβοδίζω ξεπροβοδώ ξεπροβοδώνω ξερίχνω ξεραίνομαι ξεραίνω ξεριζώνομαι
 ξερνάω ξερνοβολώ ξερνώ ξεροβήχω ξεροκαταπίνω ξεροκοκκινίζω ξεροσταλιάζω
 ξεροψήνομαι ξεροψήνω ξεσέρνω ξεσαβουρώνω ξεσαλώνω ξεσαμαρώνω ξεσβερκιάζομαι
 ξεσελώνω ξεσηκώνομαι ξεσηκώνω ξεσκάζω ξεσκάω ξεσκίζομαι ξεσκίζω ξεσκαλίζω
 ξεσκαρτάρω ξεσκατίζω ξεσκατώνω ξεσκεπάζω ξεσκλαβώνω ξεσκολίζω ξεσκονίζω
 ξεσκουντώ ξεσκουριάζω ξεσκουφώνομαι ξεσκουφώνω ξεσπάζω ξεσπάω ξεσπαθώνω
 ξεσποριάζω ξεσπώ ξεσταχυάζω ξεστηθώνομαι ξεστηθώνω ξεστολίζω ξεστομίζω
 ξεστραβώνω ξεστρατίζω ξεστρώνομαι ξεστρώνω ξεσυνερίζομαι ξεσυννεφιάζω
 ξεσφίγγω ξεσφραγίζω ξεσχίζω ξεσύρω ξεταπώνω ξετελεύω ξετεντώνω ξετιμώ ξετινάζω
 ξετρελαίνω ξετρυπάω ξετρυπώνω ξετσιπώνομαι ξετυλίγομαι ξετυλίγω ξευτελίζω
 ξεφαντώνω ξεφεύγω ξεφιτιλίζω ξεφιτιλώ ξεφλουδίζομαι ξεφλουδίζω ξεφορμάρω
 ξεφορτώνω ξεφουρνίζω ξεφουσκώνομαι ξεφουσκώνω ξεφράζω ξεφτίζω ξεφτιλίζομαι
 ξεφτώ ξεφυλλίζω ξεφυσώ ξεφυτρώνω ξεφωνίζω ξεφωνώ ξεχάνω ξεχέζω ξεχαρβαλώνομαι
 ξεχειλίζω ξεχειλώνω ξεχειμάζω ξεχειμωνιάζω ξεχειρίζω ξεχερσώνω ξεχνάω
 ξεχνώ ξεχολιάζω ξεχοντρίζω ξεχορταριάζω ξεχρεώνομαι ξεχρεώνω ξεχωνιάζω
 ξεχύνομαι ξεχύνω ξεχώνομαι ξεχώνω ξεψαρώνω ξεψαχνίζω ξεψειρίζω ξεψυχώ ξεϊδρώνω
 ξεύρω ξηγώ ξηλώνω ξημαρίζω ξημεροβραδιάζομαι ξημερώνει ξημερώνομαι ξημερώνω
 ξιδιάζω ξινίζω ξιπάζομαι ξιπάζω ξιπολιέμαι ξιφομαχώ ξιφουλκώ ξοδεύομαι ξοδεύω
 ξολοθρεύω ξομολογιέμαι ξομολογώ ξομπλιάζω ξορκίζω ξουραφίζω ξοφλάω ξυλίζω
 ξυλιάζω ξυλογραφώ ξυλοκοπώ ξυλουργώ ξυλοφορτώνομαι ξυλοφορτώνω ξυπνώ
 ξυπολυέμαι ξυρίζω ξυραφίζομαι ξυραφίζω ξυστρίζω ξωμένω ξύνομαι ξύνω ξύπνα ξύω
 οβελίζομαι οβελίζω ογκανίζω ογκούμαι ογκώμαι ογκώνομαι ογκώνω ογραίνω οδεύω
 οδηγούμαι οδηγώ οδοιπορώ οδοστρώνω οδύρομαι οζονίζω οζοντίζω
 οιακίζω οιακοστροφώ οικίζω οικειοποιούμαι οικειούμαι οικειώνομαι οικοδομούμαι
 οικοκυρεύω οικονομώ οικοπεδοποιώ οικουρώ οικτίρω οικώ οιμώζω οιστρηλατούμαι
 οιωνίζομαι οιωνοσκοπώ οκνεύω οκνώ οκταπλασιάζω ολιγοπιστώ ολιγοστεύω ολιγοψυχώ
 ολισθαίνω ολοκληρώνομαι ολοκληρώνω ολολύζω ολοφύρομαι ομαδοποιώ ομαλίζω
 ομαλοποιώ ομαλύνω ομιλώ ομνύω ομογνωμονώ ομοδοξώ ομοιάζω ομοιοκαταληκτώ
 ομοιώνω ομολογώ ομονοώ ομορφαίνω ομοσιτώ ομοφηφώ ομοφρονώ ομοφωνώ ομπυάζω
 ομόνω ονειδίζω ονειρεύομαι ονειριάζομαι ονειροβατώ ονειροπολώ ονειρώττω
 ονομάζω ονοματίζω ονοματοθετώ ονοματοποιώ οντουλάρω οξειδοφωσφορυλιώνω
 οξειδώνω οξεοποιώ οξιδώνομαι οξιδώνω οξυγονοκολλώ οξυγονώ οξυγονώνω οξυτονώ
 οπαλίζω οπισθογραφώ οπισθοδρομώ οπισθοχωρώ οπλίζομαι οπλίζω οπλομαχώ οπλοφορώ
 ορέγομαι ορίζομαι ορίζω οραματίζομαι οργίζομαι οργίζω οργανώνομαι οργανώνω
 οργώ οργώνομαι οργώνω ορειχαλκώνω ορθιάζω ορθογραφώ ορθοποδίζω ορθοποδώ
 ορθοτονώ ορθοφρονώ ορθώνομαι ορθώνω οριζοντιώνομαι οριζοντιώνω οριοθετούμαι
 οριστικοποιούμαι οριστικοποιώ ορκίζομαι ορκίζω ορκοδοτώ ορκωμοτώ ορμάω ορμίζω
 ορμηνεύω ορμώ ορμώμαι οροθετώ ορρωδώ ορτσάρω ορφανίζω ορφανεύω ορχούμαι ορύσσω
 ορώ οσμίζομαι οστεοποιώ οστεώνομαι οστεώνω οσφραίνομαι ουρανοβατώ ουριοδρομώ
 ουρώ ουσιαστικοποιούμαι οφείλομαι οφείλω οχεύω οχλοκρατούμαι οχταπλασιάζω
 οχυρώνω πάγω πάλλομαι πάλλω πάσχω πάω πέλω πέμπομαι πέμπω πένομαι πέποιθα
 πέρδομαι πέτομαι πέφτω πήζω πίνω πίπτω πίπτω παίζομαι παίζω παίρνομαι παίρνω
 πααίνω παγαίνω παγανίζω παγιδεύομαι παγιδεύω παγιοποιώ παγιώνομαι παγιώνω
 παγοδρομώ παγοποιώ παγουδιάζω παγουδιώ παγώνω παζαρεύω παθαίνω παθητικοποιώ
 παθοπλαντάζω παιανίζω παιγνιδίζω παιδαγωγώ παιδεύω παιδιακίζω παιδιαρίζω
 παιδοποιώ παιζογελώ παινεύομαι παινεύω παινώ παιχνιδίζω παιχνιδιαρίζω πακετάρω
 πακτώνω παλαίω παλαβώνω παλαιώνομαι παλαιώνω παλαμίζω παλαντζάρω παλεύω
 παλινδρομώ παλιννοστώ παλινορθώνομαι παλινορθώνω παλινωδώ παλιώνομαι παλιώνω
 παλουκώνω πανάρω πανίζω πανηγυρίζω πανθομολογούμαι πανιάζω πανικοβάλλομαι
 πανουκλιάζω παντέχω παντελονιάζω παντρεύομαι παντρεύω παντρολογιέμαι
 παντρολογώ παξιμαδιάζω παπαγαλίζω παπαδοκρατούμαι παπαριάζω παπλώνω
 παπουτσώνω παράγομαι παράγω παράκειμαι παρέλκω παρέρχομαι παρέχομαι παρέχω
 παραέχω παραβάλλομαι παραβάλλω παραβαίνω παραβαραίνω παραβαρύνω παραβγαίνω
 παραβλάπτω παραβλέπομαι παραβράζω παραγίνομαι παραγγέλλομαι παραγγέλλω
 παραγεμίζομαι παραγεμίζω παραγεράζω παραγερνώ παραγιομίζω παραγκωνίζομαι
 παραγνωρίζομαι παραγνωρίζω παραγοντοποιούμαι παραγοντοποιώ παραγράφομαι
 παραγραμματίζω παραδέρνω παραδέχομαι παραδίδεται παραδίδομαι παραδίδω
 παραδειγματίζομαι παραδειγματίζω παραδειγματολογώ παραδιαβάζω παραδοξολογώ
 παραείμαι παραζαλίζω παραζεσταίνομαι παραζεσταίνω παραθέτω παραθαρρεύω
 παραθερίζω παραθερμαίνομαι παραθερμαίνω παραθυμώνω παραινώ παραιτούμαι παραιτώ
 παρακάθομαι παρακάμπτω παρακάνω παρακαλούμαι παρακαλώ παρακαταθέτω παρακεντώ
 παρακινούμαι παρακινώ παρακλαδεύω παρακμάζω παρακοιμάμαι παρακοιμούμαι
 παρακολουθώ παρακούω παρακρατούμαι παρακρατώ παρακωλύομαι παρακωλύω παραλέω
 παραλαμβάνομαι παραλαμβάνω παραλαντίζω παραλείπω παραληρώ παραλλάζω
 παραλλάσσω παραλληλίζομαι παραλληλίζω παραλογίζομαι παραλογιάζω παραλύω
 παραμακραίνω παραμακρύνω παραμελώ παραμερίζομαι παραμερίζω παραμετροποιώ
 παραμονεύω παραμορφώνω παραμπαίνω παραμπουκώνω παραμυθιάζομαι παραμυθιάζω
 παραμυθούμαι παρανομάζω παρανομιάζω παρανομώ παρανοώ παρανυστάζω παραξενεύομαι
 παραξενιάζω παραξηλώνω παραξοδεύομαι παραξοδεύω παραξοδιάζω παραπέμπομαι
 παραπέφτω παραπίνω παραπαίρνω παραπαίω παραπατώ παραπαχαίνω παραπείθω παραπετώ
 παραπλέω παραπλανιέμαι παραπλανώ παραπλανώμαι παραπληροφορούμαι παραπληροφορώ
 παραποιώ παραπονιέμαι παραπονιούμαι παραπονούμαι παραρίχνω παραρρέω
 παρασέρνω παρασημαίνω παρασημοφορούμαι παρασημοφορώ παρασιτώ παρασιωπώ
 παρασκευάζω παρασπονδώ παραστέκομαι παραστέκω παρασταίνω παραστρατίζω
 παρασύρομαι παρασύρω παρατάσσομαι παρατάσσω παρατίθεμαι παρατείνω
 παρατεντώνω παρατηρώ παρατηρῶ παρατιέμαι παρατιμονιάζω παρατρέπω παρατρέχω
 παρατραβώ παρατρώγω παρατρώω παρατυγχάνω παρατυπώ παρατυπώνω παρατώ παραφέρνω
 παραφθείρω παραφορτώνομαι παραφορτώνω παραφουντώνω παραφουσκώνομαι
 παραφράζω παραφρονώ παραφυλάγω παραφυλάω παραφωνάζω παραφωνώ παραχέζω
 παραχαράσσομαι παραχαράσσω παραχαϊδεύω παραχειμάζω παραχοντραίνω παραχωρούμαι
 παραχώνομαι παραχώνω παραψένω παραψήνω παραωριμάζω παρεδρεύω παρεισάγω
 παρεισφρέω παρεκβαίνω παρεκκλίνω παρεκτείνω παρεκτρέπομαι παρελαύνω
 παρελκύω παρεμβάλλομαι παρεμβάλλω παρεμβαίνω παρεμπίπτω παρεμποδίζω παρεμφαίνω
 παρενθέτω παρεννοώ παρενοχλούμαι παρενοχλώ παρεντίθεμαι παρεξηγιέμαι
 παρεξηγώ παρεπιδημώ παρερμηνεύομαι παρερμηνεύω παρετυμολογώ παρευρίσκομαι
 παριστάνω παριστώ παρκάρω παρκετάρω παρλάρω παροικώ παρομοιάζω παρομοιώνω
 παροξύνω παροπλίζω παροργίζω παρορμώ παρορμώμαι παρορώ παροτρύνω παρουσιάζομαι
 παροχετεύομαι παροχετεύω παρωδούμαι παρωδώ παρωθώ πασάρω πασέρνω πασαλείβω
 πασκάζω πασκίζω πασπαλίζομαι πασπαλίζω πασπατεύγω πασπατεύω πασσαλώνω
 παστρεύγω παστρεύω παστώνω πασχάζω πασχίζω πατάσσομαι πατάσσω πατάω πατεντάρω
 πατικώνω πατινάρω πατριαρχεύω πατριαρχώ πατρονάρω πατσίζω πατσαβουριάζομαι
 παττίζω πατώ πατώνω παφλάζω παχαίνω παχνιάζω παχτώνω παχύνω παύομαι παύω
 πείθω πεδικλώνομαι πεδικλώνω πεδιλώνω πεζεύω πεζογραφώ πεζοδρομώ πεζολογώ
 πεζοπορώ πεθαίνω πεθυμώ πειθαναγκάζομαι πειθαναγκάζω πειθαρχώ πεινάω πεινώ
 πειράζω πειραματίζομαι πειρατεύω πειρώμαι πεισματώνω πεισμώνω πελαγίζω
 πελαγώνω πελεκάω πελεκίζω πελεκιέμαι πελεκώ πελιδνούμαι πενηνταρίζω πενθηφορώ
 πενταπλασιάζω πεντοβολώ περίκειμαι περαίνω περαιώνω περατώνω περδικλώνω
 περεχύνω περεχώ περηφανεύομαι περιάγω περιάπτω περιέρχομαι περιέχω περιίπταμαι
 περιαλείφω περιαρπάζω περιαυγάζω περιαυτολογώ περιβάλλομαι περιβάλλω περιβλέπω
 περιγαμώ περιγελώ περιγλύφω περιγράφομαι περιγράφω περιδένω περιδιαβάζω
 περιδινώ περιδρομιάζω περιελίσσομαι περιελίσσω περιεργάζομαι περιζωννύω
 περιηγούμαι περιθάλπω περιθωριοποιούμαι περιθωριοποιώ περικάμπτω περικαλύπτω
 περικείρω περικλαδεύω περικλείνω περικλείομαι περικλείω περικλύζομαι περικλύζω
 περικυκλώνομαι περικυκλώνω περικόβω περικόπτω περιλάμπω περιλαβαίνω
 περιλαμβάνω περιλούζω περιλούω περιμένω περιμαζεύω περιμαζώνω περιμαντρώνω
 περιορίζομαι περιορίζω περιπίπτω περιπαίζω περιπατώ περιπλέκομαι περιπλέκω
 περιπλανιέμαι περιπλανώμαι περιποιέμαι περιποιούμαι περιποιώ περιπολώ
 περιρράπτω περιρρέω περιρραίνω περισκοπώ περισπώ περισσεύω περιστέλλω
 περιστοιχίζω περιστρέφομαι περιστρέφω περισυλλέγω περισυνάγω περισφίγγω
 περισώζω περισώνω περιτέμνω περιταφρώ περιτειχίζω περιτοιχίζω περιτρέχω
 περιττεύω περιττολογώ περιττώνω περιτυλίγω περιυβρίζω περιφέρομαι περιφέρω
 περιφράζω περιφράσσω περιφρονώ περιφρουρώ περιχέω περιχαράζομαι περιχαράζω
 περιχαράσσω περιχαρακώνομαι περιχαρακώνω περιχρίω περιχρυσώνω περιχύνω περιχώ
 περνιέμαι περνοδιαβαίνω περνώ περονιάζω περπατώ περώ πετάγομαι πεταλουδίζω
 πεταρίζω πετιέμαι πετροβολώ πετρώνω πετσιάζω πετσικάρω πετσοκόβω πετσώνω
 πετώ πηγάζω πηγαίνω πηγαινοέρχομαι πηγαινοφέρνω πηγαινόρχομαι πηδάω πηδαλιουχώ
 πηδώ πηκτωματοποιώ πηλαλάω πηλαλώ πηλοβατώ πιάνομαι πιάνω πιέζομαι πιέζω
 πιθανεύομαι πιθανολογώ πιθηκίζω πιθυμώ πιθώνω πικάρω πικαρίζω πικρίζω
 πικραίνω πικραναστενάζω πικροκαρδίζω πιλαλάω πιλαλώ πιλατεύω πιλοτάρω πιλοφορώ
 πιπίζω πιπερίζω πιπερώνω πιπιλίζω πιπιλώ πιπώνω πιρουνιάζω πισκαλώ πισσώνομαι
 πιστεύω πιστοδοτώ πιστολίζω πιστοποιούμαι πιστοποιώ πιστοχρεώνω πιστώνω
 πισωδρομώ πιτηδεύομαι πιτσιλάω πιτσιλίζω πιτσιλώ πλάθομαι πλάθω πλάσσω πλάττω
 πλέκω πλένομαι πλένω πλέχω πλέω πλήττομαι πλήττω πλαγιάζω πλαγιοδετώ
 πλαγιοδρομώ πλαγιοποδίζω πλαγιοφυλάσσω πλαγιοφυλακώ πλαισιώνομαι πλαισιώνω
 πλακοστρώνω πλακουτσώνω πλακώνομαι πλακώνω πλαλώ πλανάρω πλανίζομαι πλανίζω
 πλανεύω πλανιέμαι πλαντάζω πλαντώ πλανώ πλανώμαι πλασάρομαι πλασάρω
 πλαστικοποιώ πλαστογραφούμαι πλαστογραφώ πλαστοπροσωπώ πλαστουργώ πλαταίνω
 πλατειάζω πλατσουκώνω πλατσουρίζω πλατύνω πλειοδοτώ πλειονοψηφώ πλειοψηφώ
 πλεονάζω πλεονεκτώ πλερώνω πλευρίζω πλευριτώνομαι πλευριτώνω πλευροκοπώ
 πληγώνομαι πληγώνω πληθαίνω πληθύνω πληκτρολογούμαι πληκτρολογώ πλημμυρίζω
 πληροφορούμαι πληροφορώ πληρώ πληρώνομαι πληρώνω πλησιάζω πλιατσικολογώ
 πλισάρω πλοηγώ πλοιαρχώ πλουμίζω πλουτίζω πλουταίνω πλουτώ πλωρίζω πλύνω πνέω
 πνίγω πνευστιώ ποδένω ποδίζω ποδηγετούμαι ποδηγετώ ποδηλατώ ποδοβολώ ποδοκροτώ
 ποδοπατιέμαι ποδοπατούμαι ποδοπατώ ποζάρω ποθώ ποικίλλω ποιμαίνομαι ποιμαίνω
 ποινικοποιούμαι ποινικοποιώ ποιούμαι ποιώ πολεμάω πολεμώ πολεμῶ πολεοδομούμαι
 πολιορκούμαι πολιορκώ πολιτεύομαι πολιτικολογώ πολιτικοποιούμαι πολιτικοποιώ
 πολλαίνω πολλαπλασιάζομαι πολλαπλασιάζω πολτοποιούμαι πολτοποιώ πολυαγαπώ
 πολυγραφούμαι πολυγραφώ πολυκαιρίζω πολυλογώ πολυμιλώ πολυνομίζω πολυξοδιάζω
 πολυπικραίνω πολυπραγμονώ πολυταξιδεύω πολυτεντώνω πολυτονίζω πολυφορτώνω
 πολυχρονάω πολυχρονίζω πολώνομαι πολώνω πομπάρω πομπεύω πομπιάζω πονηρεύομαι
 πονθιάζω πονοκεφαλιάζω πονοκεφαλώ πονοῦμαι ποντάρω ποντίζομαι ποντίζω
 πονώ πονῶ πορίζομαι πορίζω πορδίζω πορεύομαι πορεύω πορθώ πορνεύω πορνογραφώ
 πορτοκαλίζω πορφυρίζω πορφυρώνω ποσάρω ποσοτικοποιώ ποστάρω ποσταίρνω ποτάζω
 ποτίζω πουδράρω πουλάω πουλεύω πουλιέμαι πουλώ πουμώνω πουντιάζω πουριάζω
 πουστίζω πουτανίζω πουτσίζω πράττω πρέπει πρέπω πρήζομαι πρήζω πρήσκω πραΰνω
 πραγματοποιούμαι πραγματοποιώ πραγματώνομαι πραγματώνω πρασινίζω πρατιγάρω
 πρεσάρω πρεσβεύω πριμάρω πριμοδοτούμαι πριμοδοτώ πριονίζομαι πριονίζω
 προάγομαι προάγω προέλκω προέρχομαι προέχει προαίνω προαγγέλλω προαγοράζω
 προαιρούμαι προαισθάνομαι προαλείφομαι προαναγγέλλω προανακρίνω προανακρούω
 προαναφλέγω προαπαγορεύω προαπαιτώ προαπαντώ προαποβιώνω προαποστέλλω
 προαποφασίζω προασκώ προασπίζομαι προασπίζω προασφαλίζω προαφαιρώ προβάλλομαι
 προβάρω προβαίνω προβαδίζω προβιβάζομαι προβιβάζω προβλέπομαι προβλέπω
 προβληματίζω προβοδίζω προβοδώνω προβοκάρω προβούλομαι προγευματίζω προγεύομαι
 προγκάρω προγκάω προγκίζω προγράφω προγραμματίζομαι προγραμματίζω προγυμνάζω
 προδίνω προδιαγράφομαι προδιαγράφω προδιαθέτω προδιατίθεμαι προδικάζω
 προειδοποιούμαι προειδοποιώ προεικάζω προεισπράττω προεκβάλλω προεκλέγω
 προεκτυπώνω προελέγχω προελαύνω προεμβάζω προενεργώ προεξάγω προεξάρχω
 προεξοφλώ προετοιμάζομαι προετοιμάζω προηγούμαι προθερμαίνομαι προθερμαίνω
 προικίζω προικοδοτώ προικοθηρώ προκάθημαι προκάνω προκαθορίζω προκαλούμαι
 προκαλώ προκαταβάλλω προκαταλαμβάνω προκαταρτίζω προκατασκευάζω προκηρύσσω
 προκινδυνεύω προκρίνομαι προκρίνω προκόβω προκόφτω προκύπτω προλέγω προλαβαίνω
 προλειαίνω προλογίζω προμαντεύω προμαχώ προμελετώ προμηθεύομαι προμηθεύω
 προμηνώ προμισθώνω προμοτάρω προνευστάζω προνεύω προνοώ προξενεύω προξενώ
 προοιμιάζομαι προοιμιάζομαι προοιωνίζομαι προοιωνίζω προορίζομαι προορίζω
 προπέμπω προπίνω προπαίρνω προπαγανδίζω προπαιδεύω προπαρασκευάζομαι
 προπαροξύνω προπηλακίζω προπλάθω προπληρώνομαι προπληρώνω προπονώ προπορεύομαι
 προσάγω προσάπτω προσέρχομαι προσέχω προσήκει προσαγορεύω προσαιγιαλώνομαι
 προσαράζω προσαράσσω προσαρμόζομαι προσαρμόζω προσαρτώ προσαρτώμαι
 προσαυξάνω προσαυξαίνω προσβάλλομαι προσβάλλω προσβέλνω προσβλέπω
 προσγειώνω προσγράφω προσδένω προσδέχομαι προσδίδω προσδίνω προσδιορίζω
 προσδοκώ προσεγγίζω προσεδαφίζομαι προσεδαφίζω προσελκύω προσεπικαλώ
 προσεταιρίζομαι προσεύχομαι προσηκώνομαι προσηλιάζω προσηλυτίζω προσηλώνομαι
 προσημαίνω προσημειώνω προσθέτω προσθαλασσώνομαι προσθαλασσώνω προσθαφαιρώ
 προσκαλώ προσκλίνω προσκολλώ προσκολλώμαι προσκομίζω προσκρούω προσκτώμαι
 προσκυρώνω προσκόπτω προσλαβαίνω προσλαμβάνομαι προσλαμβάνω προσλιμενίζομαι
 προσμαρτυρώ προσμειδιώ προσμετρώ προσμοιάζω προσομοιάζω προσονομάζω
 προσορμίζω προσπέφτω προσπίπτω προσπαθώ προσπελάζω προσπερνώ προσποιούμαι
 προσράπτω προσροφώ προσροφώμαι προσσεληνώνω προστάζω προστίθεμαι προστατεύω
 προστρέχω προστρίβω προστυχαίνω προστυχεύω προσυδατώνω προσυλλογίζομαι
 προσυπογράφω προσφέρομαι προσφέρω προσφεύγω προσφωνώ προσχεδιάζω προσχηματίζω
 προσχώνω προσωπογραφώ προσωποκρατώ προσωποληπτώ προσωποποιούμαι προσωποποιώ
 προτίθεμαι προτείνω προτειχίζω προτελευτώ προτιμολογώ προτιμώ προτονίζω
 προτρέπω προτρέχω προφέρω προφασίζομαι προφητεύω προφθάνω προφτάνω προφταίνω
 προφυλάγω προφυλάσσομαι προφυλάσσω προφυλάω προφυλακίζω προχέω προχειρίζω
 προχρονολογώ προχωράω προχωρώ προωθώ προϊδεάζω προϋπάρχω προϋπαντώ προϋπηρετώ
 προϋποθέτω προϋπολογίζω προϋποτίθεται προϋπόσχομαι προϋφίσταμαι πρυμάρω
 πρυματσάρω πρυμνοδετώ πρυτανεύω πρωθυπουργεύω πρωταγωνιστώ πρωταρχίζω
 πρωτεύω πρωτοανοίγω πρωτοβάζω πρωτοβγάζω πρωτοβγαίνω πρωτοβλέπω πρωτογεννώ
 πρωτοδοκιμάζω πρωτοεμφανίζομαι πρωτοθυμάμαι πρωτοκαθίζω πρωτοκολλώ πρωτολέω
 πρωτομαθαίνω πρωτομιλώ πρωτοπηγαίνω πρωτοπιάνω πρωτοπορώ πρωτοστατώ πρωτοτρώγω
 πρωτοφορώ πρωτοφτάνω πρόγκημα πρόκειται πρόσκειμαι πτήσσω πτίσσω πταίω
 πτερυγίζω πτερώνω πτοούμαι πτοώ πτοῶ πτυελίζω πτυχώνω πτωχαίνω πτωχεύω πτύω
 πυγμαχώ πυκνοκατοικούμαι πυκνοφυτεύω πυκνώνω πυορροώ πυρέσσω πυρακτώνομαι
 πυργώνω πυρηνοποιώ πυριτιοποιώ πυροβολώ πυροδοτώ πυρπολούμαι πυρπολώ πυρπολῶ
 πωλούμαι πωλώ πωματίζω πωρώνομαι πωρώνω ράβω ράνω ράπτω ρέβω ρέγομαι ρέγχω
 ρέω ρίπτω ρίχνομαι ρίχνω ρίχτω ραΐζω ραίνω ραβδίζω ραβδομαχώ ραβδοσκοπώ
 ραγίζω ραγολογώ ραδιοτηλεφωνώ ραδιουργώ ραθυμώ ρακιτζίζω ρακοσυλλέγω ρακοφορώ
 ραμολίρω ραμφίζω ραντίζω ραπάρω ραπίζω ραπώνω ραφινάρω ραχατεύω ρεγουλάρω
 ρεζιλεύω ρεκάζω ρεκλαμάρω ρελιάζω ρεμβάζω ρεμεντζάρω ρεμετζάρω ρεμιντζάρω
 ρεμπελεύω ρεμπετεύω ρεπάρω ρεστάρω ρετουσάρω ρευματοδοτούμαι ρευματοδοτώ
 ρευστοποιώ ρεφάρω ρεφενίζω ρεύγομαι ρεύομαι ρεύω ρηγνύω ρημάζω ρημάσω ρημώνω
 ρητινώνω ρητορεύω ριγώ ριγώνω ριζοβολώ ριζοδοντιάζω ριζολογώ ριζοσπαστικοποιώ
 ρικνούμαι ρικνώνομαι ρικνώνω ριμάρω ρινίζω ριπίζω ριπτάζομαι ρισκάρω
 ροβολάω ροβολώ ρογιάζω ροδίζω ροδανίζω ροδοκοκκινίζω ροζιάζω ροζονάρω
 ροκάρω ροκανίζω ρολάρω ρομαντζάρω ρουθουνίζω ρουμπώνω ρουπώνω ρουσφετολογώ
 ρουφιανεύω ρουφώ ρουχουνίζω ροφώ ροχαλίζω ρυάζομαι ρυθμίζω ρυμοτομώ ρυμουλκώ
 ρυπαίνω ρυπαρογραφώ ρυτιδιάζω ρυτιδώνω ρωθωνίζω ρωτακίζω ρωτώ ρώομαι σάζω
 σέπομαι σέρνομαι σέρνω σήπομαι σίζω σαβανώνω σαβουριάζω σαβουρώνω σαγίζω
 σακατεύω σακιάζω σακουλεύομαι σακουλιάζω σαλαγώ σαλεύγω σαλεύω σαλιάζω
 σαλιώνω σαλντώ σαλπάρω σαλπίζω σαλτάρω σαμαρώνομαι σαμαρώνω σαμπανιάζω
 σανιδώνω σαπίζω σαπουνίζω σαπωνοποιώ σαραβαλιάζω σαρακιάζω σαρακοστίζω
 σαραντίζω σαρανταρίζω σαρκάζω σαρκώνω σαρώνω σασιρντίζω σαστίζω σατινάρω
 σαφηνίζω σαχλαμαρίζω σαχλιάζω σαψαλιάζω σαϊτεύω σβένω σβήνομαι σβήνω σβανάρω
 σβαρνώ σβολιάζω σβολώνω σβουρίζω σβω σβωλιάζω σγουραίνω σγουρώνω σείομαι σείω
 σεγκοντάρω σειέμαι σειώ σεκλεντίζομαι σεκλεντίζω σεκλετίζομαι σεκλετίζω
 σελαγίζω σελεμίζω σελεμιάζω σεληνιάζομαι σελιδοποιούμαι σελιδοποιώ σελιδώνω
 σεμνολογώ σεμνύνομαι σενιάρω σεντονιάζω σεντράρω σερβίρομαι σερβίρω σεργιανάω
 σερφάρω σετάρω σηκώνομαι σηκώνω σημαίνω σημαδεύω σημαιοστολίζω σηματοδοτώ
 σημειώνω σιάζω σιάχνω σιαλίζω σιαλώνω σιγάζω σιγοβράζω σιγοβρέχει σιγοκαίω
 σιγομουρμουρίζω σιγοντάρω σιγοπίνω σιγοτραγουδώ σιγουράρω σιγουρεύομαι
 σιγοψιθυρίζω σιγώ σιδερώνω σιμώνω σινιάρω σιργουλεύγω σιροπιάζω σιτίζω σιτεύω
 σιχτιρίζω σιωπώ σκάβω σκάζω σκάνω σκάπτω σκάφτω σκάω σκέπτομαι σκέπτω σκέπω
 σκίζομαι σκίζω σκαλίζω σκαλεύω σκαλώνω σκαμπάζω σκαμπανεβάζω σκαμπιλίζω
 σκανδαλοθηρώ σκανδαλολογώ σκανταγιάρω σκανταλίζω σκανταλιάρω σκαντζάρω
 σκαπετίζω σκαπετώ σκαπουλάρω σκαρίζω σκαρδαμύσσω σκαριφίζω σκαριφώ σκαρτάρω
 σκαρφίζομαι σκαρφαλώνομαι σκαρφαλώνω σκαρώνω σκατώνω σκαφιδιάζω σκαφιδώνω
 σκεδάζω σκεπάζομαι σκεπάζω σκεπαρνίζω σκερτσάρω σκευάζω σκευωρώ σκηνογραφώ
 σκηνώ σκιάζω σκιαγραφώ σκιαμαχώ σκιρτώ σκιτσάρω σκλαβώνω σκληρίζω σκληραίνω
 σκληρύνω σκολάζω σκολιώ σκολνώ σκολοπίζω σκονίζομαι σκονίζω σκοντάβω σκοντάφτω
 σκοπώ σκοράρω σκορακίζω σκορπάω σκορπίζομαι σκορπίζω σκορπώ σκοτίζομαι σκοτίζω
 σκοτεινιάζω σκοτιδιάζω σκοτοδινιώ σκοτώνομαι σκοτώνω σκουληκιάζω σκουντάω
 σκουντουφλώ σκουντώ σκουπίζομαι σκουπίζω σκουραίνω σκουριάζω σκουροφέρνω
 σκούζω σκρολάρω σκυθρωπάζω σκυθρωπιάζω σκυλεύω σκυλιάζω σκυλοβαριέμαι
 σκυλοτρώγομαι σκυροδετώ σκωληκιώ σκύβω σκώπτω σμίγω σμαλτώνω σμικρύνω
 σμιλεύω σμπαραλιάζω σνιφάρω σνομπάρω σοβαντίζω σοβαρεύομαι σοβαρεύω σοβαρολογώ
 σοβεντάρω σοβερτάρω σοβώ σοδεύω σοδιάζω σοδομίζω σοκάρομαι σοκάρω σολιάζω
 σονάρω σοροπιάζω σορτάρω σοτάρω σουβαντίζω σουβλίζω σουλαντίζω σουλαντώ
 σουλατσέρνω σουλουπώνομαι σουλουπώνω σουμάρω σουπάρω σουρίζω σουραυλίζω
 σουρομαδιέμαι σουρομαδώ σουρομαλλιάζω σουρουπώνει σουρτουκεύω σουρώνω
 σουσουμιάζω σουτάρω σουφρώνω σοφάρω σοφίζομαι σοφιλιάζω σοφιστεύομαι σούρνω
 σπάζω σπάνω σπάω σπέρνω σπαζοκεφαλιάζω σπαθίζω σπανίζω σπαράζομαι σπαράζω
 σπαργώ σπαρταράω σπαρταρίζω σπαρταρώ σπαταλιέμαι σπαταλώ σπείρω σπεδίζω
 σπερμολογώ σπεύδω σπιθίζω σπιθοβολώ σπικάρω σπιλώνω σπινθηρίζω σπινθηροβολώ
 σπιουνάρω σπιουνεύω σπιουνιάρω σπιρουνίζω σπιρουνιάζω σπιτώνω σπλαχνίζομαι
 σπογγίζω σποριάζω σπορκαρίζομαι σπουδάζω σπουδαιολογώ σπουδαρχώ σπρώχνομαι
 σπυριάζω σπω στάζω στέκομαι στέκω στέλνω στένω στέργω στέφω στήνομαι στήνω
 στίζω στίλβω σταβλίζω σταδιοδρομώ σταδιοποιώ σταθεροποιούμαι σταθεροποιώ
 σταθμεύω σταλάζω σταλίζω σταλιάζω σταματώ σταμπάρω στανιάρω στασιάζω
 σταυροδοτώ σταυροκοπιέμαι σταυροκοπούμαι σταυροφορώ σταυρώνω σταφιδιάζω
 σταχολογώ σταχτιάζω σταχτώνω σταχυάζω σταχυολογούμαι σταχυολογώ σταχώνω στείβω
 στεγανοποιούμαι στεγανοποιώ στεγνώνω στειλιαρώνω στειρεύω στειροποιώ στειρώνω
 στελεχώνω στελιάζω στενάζω στεναχωράω στεναχωριέμαι στεναχωρώ στενεύω
 στενοχωριέμαι στενοχωρώ στερεοποιούμαι στερεοποιώ στερεοτυπώ στερεοτυπώνω
 στερεώνομαι στερεώνω στεριώνω στερούμαι στερφεύω στερώ στεφανηφορώ
 στεφανώνω στηθοδέρνομαι στηθοκοπιέμαι στηθοσκοπώ στηλιτεύω στηλώνω στημονιάζω
 στηρίζω στιγματίζω στιλβώνω στιλιζάρω στιμάρω στιχουργώ στλεγγίζω στοιβάζω
 στοιχίζω στοιχειοθετώ στοιχειώνω στοιχηματίζω στοιχώ στοκάρω στολίζομαι
 στολοδρομώ στομαχιάζω στομφάζω στομώνω στοπάρω στορίζω στουκάρω στουμπίζω
 στουπώνω στοχάζομαι στοχεύω στρέγω στρέφομαι στρέφω στρίβω στραβίζω
 στραβολαιμιάζω στραβομουτσουνιάζω στραβοπατώ στραβώνω στραγγίζω στραγγαλίζω
 στραμπουλώ στραπατσάρω στραταρίζω στρατεύομαι στρατηγώ στρατιωτικοποιώ
 στρατολογούμαι στρατολογώ στρατοπεδεύω στρατουλίζω στρατωνίζομαι στρατωνίζω
 στρεσάρω στρεψοδικώ στριγκλίζω στριμώχνομαι στριμώχνω στριφογυρίζω στριφογυρνώ
 στροβιλίζομαι στροβιλίζω στρογγυλαίνω στρογγυλεύω στρογγυλοκάθομαι
 στρογγυλώνω στρουθοκαμηλίζω στροφοδινούμαι στρώνομαι στρώνω στυλώνω στυπώνω
 στύβω στύφω συβάζω συγγενεύω συγγηράσκω συγγράφω συγκαίγομαι συγκαίομαι
 συγκαλύπτω συγκαλώ συγκατέχω συγκαταβαίνω συγκατακλίνομαι συγκαταλέγω
 συγκαταριθμώ συγκατατάσσω συγκατατίθεμαι συγκατοικώ συγκεκριμενοποιούμαι
 συγκεντρώνομαι συγκεντρώνω συγκεράζομαι συγκεράζω συγκερνώ συγκεφαλαιώνω
 συγκινώ συγκλίνω συγκλείω συγκληρονομώ συγκλονίζω συγκοινωνώ συγκολλιέμαι
 συγκομίζω συγκρίνομαι συγκρίνω συγκρατιέμαι συγκρατούμαι συγκρατώ συγκροτώ
 συγκυβερνώ συγκωδωνίζω συγκόπτομαι συγυρίζομαι συγυρίζω συγχέω συγχαίρω
 συγχρονίζω συγχρωτίζομαι συγχωνεύομαι συγχωνεύω συγχωρώ συγχύζομαι συγχύζω
 συζευγνύω συζητώ συζώ συκοφαντώ συλλέγω συλλαβίζω συλλαβαίνω συλλαμβάνω
 συλλογίζομαι συλλογιέμαι συλλογούμαι συλλυπούμαι συλούμαι συλώ συμβάλλομαι
 συμβαίνει συμβαίνω συμβαδίζω συμβασιλεύω συμβιβάζομαι συμβιβάζω συμβιώνω
 συμβολαιογραφώ συμβολοποιώ συμβουλεύομαι συμβουλεύω συμμαζεύομαι συμμαζεύω
 συμμαθητεύω συμμαχώ συμμειγνύω συμμερίζομαι συμμετέχω συμμορφώνομαι συμμορφώνω
 συμπάσχω συμπίνω συμπίπτω συμπαθώ συμπανηγυρίζω συμπαραθέτω συμπαρασέρνω
 συμπαραστέκω συμπαρασύρω συμπαρατάσσομαι συμπαρομαρτώ συμπεθερεύω συμπεθεριάζω
 συμπεριλαμβάνω συμπεριφέρομαι συμπηγνύω συμπιάνω συμπιέζομαι συμπιέζω συμπιλώ
 συμπλέκομαι συμπλέκω συμπλέω συμπληρώνω συμπολεμώ συμπολιτεύομαι συμπονώ
 συμποσιάζω συμποσούμαι συμπράττω συμπροεδρεύω συμπροφέρω συμπρωταγωνιστώ
 συμπτύσσω συμπυκνώνομαι συμπυκνώνω συμπώ συμφέρει συμφέρω συμφεροντολογώ
 συμφοιτώ συμφράζομαι συμφωνώ συμφύομαι συμφύρομαι συμφύρω συμψηφίζω συνάγω
 συνάζω συνάπτω συνάρχω συνάω συνέλκω συνέρχομαι συνέχομαι συνέχω συνίσταμαι
 συναγείρω συναγελάζομαι συναγωνίζομαι συναδελφώνομαι συναθλούμαι συναθροίζω
 συναιρώ συναισθάνομαι συνακολουθώ συνακροώμαι συναλλάζω συναλλάσσομαι
 συναναστρέφομαι συναντιέμαι συναντώ συναπαντιέμαι συναπαντώ συναπαρτίζω
 συναποκομίζω συναποτελώ συναποφασίζω συναρθρώνω συναριθμώ συναρμολογούμαι
 συναρμόζω συναρπάζω συναρτώ συναρτώμαι συνασπίζομαι συνασπίζω συναχώνομαι
 συνδέομαι συνδέω συνδαυλίζω συνδειπνώ συνδιαλέγομαι συνδιαλλάσσω
 συνδικάζω συνδικαλίζομαι συνδράμω συνδυάζω συνεγείρω συνεδριάζω
 συνειδητοποιώ συνεισφέρω συνεκπαιδεύω συνεκτιμώ συνεκφέρω συνεκφωνώ
 συνενώνομαι συνενώνω συνεξετάζω συνεορτάζω συνεπάγομαι συνεπαίρνω συνεπικουρώ
 συνερίζομαι συνεργάζομαι συνεργώ συνετίζω συνεταιρίζομαι συνευθύνομαι
 συνεφέλκω συνεφέρνω συνεφελκύω συνεχίζω συνηγορώ συνηθίζω συνηχώ συνθέτω
 συνθηματολογώ συνθλίβομαι συνθλίβω συνιστώ συνιστώμαι συννεφιάζω συνοδεύομαι
 συνοδοιπορώ συνοικίζω συνοικώ συνομιλώ συνομολογώ συνονθυλεύω συνορίζομαι
 συνουσιάζομαι συνοφρυώνομαι συνοψίζω συντάσσομαι συντάσσω συντέμνω συντήκω
 συνταγογραφώ συνταιριάζω συνταξιδεύω συνταξιοδοτούμαι συνταξιοδοτώ συνταράζω
 συνταυλίζω συνταυτίζομαι συνταυτίζω συντείνω συντελεύω συντελώ συντηρούμαι
 συντηρῶ συντομεύω συντονίζω συντρέχω συντρίβομαι συντρίβω συντροφεύω συντρώγω
 συντυγχάνω συντυχάννω συντυχαίνει συντυχαίνω συνυπάρχω συνυπηρετώ συνυποβάλλω
 συνυπολογίζω συνυπόσχομαι συνυφαίνω συνωθούμαι συνωθώ συνωμοτώ συνωνυμώ
 συνωστίζομαι συρίζω συρματοποιώ συρράπτω συρρέω συρρικνώνομαι συρρικνώνω
 συσκευάζω συσκοτίζω συσπειρώνω συσπουδάζω συσπώ συσπώμαι συσσωματώνω συσσωρεύω
 συστέλλω συσταχώνομαι συσταχώνω συστεγάζομαι συστηματοποιώ συστοιχώ συστρέφω
 συσφίγγω συσχετίζομαι συσχετίζω συχνάζω συχναναστενάζω συχνοβλέπω συχνορωτάω
 συχωρώ συχύζω σφάζω σφάλλω σφίγγω σφαγιάζω σφαδάζω σφαλίζω σφαλνώ σφαλώ
 σφεντονώ σφετερίζομαι σφηνώνω σφιχτοδένω σφουγγίζω σφουγγαρίζω σφραγίζω σφριγώ
 σφυράω σφυρίζω σφυρηλατώ σφυροκοπώ σφυρώ σφύζω σχάζω σχίζω σχεδιάζω
 σχεδιογραφώ σχετίζομαι σχετίζω σχετλιάζω σχηματίζομαι σχηματίζω σχηματοποιώ
 σχοινομετρώ σχολάζω σχολαστικίζω σχολιάζω σχολνώ σχολώ σωληνώνω σωματοποιούμαι
 σωπαίνω σωρεύομαι σωρεύω σωριάζω σωροβολιάζομαι σωφρονίζω σύγκειμαι σύρνω σύρω
 σώζω σώνω τάζομαι τάζω τάσσομαι τάσσω τέμνομαι τέμνω τέρπομαι τέρπω τήκω
 τίκτω τίλλω τίλλω τίνω ταΐζω ταβανώνω ταγίζω ταγγίζω ταγκίζω ταγκιάζω
 ταιριάζω τακάρω τακτοποιούμαι τακτοποιώ ταλαιπωρούμαι ταλαιπωρώ ταλανίζω
 ταλαντεύω ταλαντώνομαι ταλιαρίζω ταμαχιάζω ταμιεύω ταμπονάρω ταμπουρώνω
 τανυέμαι τανυούμαι τανύζω τανύομαι τανύω ταξιδεύω ταξιθετώ ταξινομώ
 ταπεινώνω ταπετσάρω ταπώνω ταράζομαι ταράζω ταράσσω ταρακουνώ ταρατσώνω
 ταριχεύομαι ταριχεύω ταστώνω ταυριάζω ταυτίζομαι ταυτίζω ταυτογνωμονώ
 ταυτολογώ ταυτοποιώ ταχταρίζω ταχτοποιώ ταχυδακτυλουργώ ταχυδρομώ ταχυμεταφέρω
 ταχύνω τείνω τεζάρω τειχίζω τειχομαχώ τεκμαίρομαι τεκμηριώνομαι τεκμηριώνω
 τεκνοποιώ τεκταίνομαι τελαρώνω τελειοποιώ τελειώνομαι τελειώνω τελεσιδικώ
 τελετουργώ τελευτώ τελεύω τελματώνομαι τελματώνω τελωνίζω τελώ τεμαχίζω
 τεμπηχιάζω τεντώνομαι τεντώνω τερατολογώ τερερίζω τερετίζω τερηδονίζομαι
 τερματίζω τερώ τεσσαρακοστίζω τεστάρω τετραβρωμιώνω τετραγωνίζω τετραπλασιάζω
 τετρατομώ τετραφθοριώνω τετραφωσφοριώνω τετραφωσφορυλιώνω τετραχλωριώνω
 τεχνάζομαι τεχνοκρατικοποιώ τεχνολογώ τεχνουργώ τζαζεύω τζαμώνω τζαρτζάρω
 τζιριτώ τζογάρω τηγανίζω τηλεγραφώ τηλεκατευθύνω τηλεφορτώνω τηλεφωνιέμαι
 τηλεφωνώ τηλεχειρίζομαι τηλεψηφίζω τηράω τιθασεύω τιμάω τιμαρεύω τιμολογώ
 τιμονιάζω τιμωρώ τιμώ τιμώμαι τινάζομαι τινάζω τιτιβίζω τιτλοδοτώ τιτλοφορώ
 τοιχίζω τοιχογραφώ τοιχογυρίζω τοιχοδομώ τοιχοκολλώ τοκίζω τολμώ τολμώμαι
 τονώνω τοξεύω τοπογραφώ τοποθετούμαι τοποθετώ τοπομαχώ τορεύω τορνάρω τορνεύω
 τουαλεταρίζομαι τουλουμιάζω τουμπάρω τουμπανίζω τουμπανιάζω τουρκεύω
 τουρλώνω τουρτουρίζω τουφεκίζω τρέμω τρέπω τρέφομαι τρέφω τρέχω τρίβομαι τρίβω
 τραβατζάρω τραβερσάρω τραβερσώνω τραβιέμαι τραβολογάω τραβολογώ τραβώ
 τραγικοποιούμαι τραγικοποιώ τραγουδώ τραγωδοποιώ τραινάρω τρακάρω τρακέρνω
 τραμπουκάρω τρανεύω τραντάζω τρανώνω τραπεζώνω τρατάρω τρατέρνω τραυλίζω
 τραυματίζω τραχηλίζω τραχύνω τρεκλίζω τρελαίνομαι τρελαίνω τρεμομανιάζω
 τρεμουλιάζω τρεμοφέγγω τρενάρω τριβελίζω τριβολίζω τριγυρίζω τριγυρνάω
 τριγωνομετρώ τριηραρχώ τρικλίζω τρικυμίζω τριπλάρω τριπλασιάζω τριποδίζω
 τριτεγγυώμαι τριτεύω τριτώνω τριφωσφορυλιώνω τριχοτομώ τρολάρω τρομάζω
 τρομοκρατώ τρομπάρω τροπολογώ τροποποιούμαι τροποποιώ τροπώνω τροφοδοτώ
 τροχίζω τροχαλώ τροχοδρομώ τροχοπεδιλοδρομώ τροχοπεδώ τρυγλοδυτώ τρυγώ τρυπάω
 τρυπώ τρυπώνω τρυφεραίνω τρυφώ τρωγαλίζω τρωγοπίνω τρύζω τρώγομαι τρώγω τρώω
 τσακίζομαι τσακίζω τσακώνομαι τσακώνω τσαλαβουτώ τσαλακώνομαι τσαλακώνω
 τσαλαπετεινίζω τσαμπουκαλεύομαι τσαμπουνάω τσαμπουνίζω τσαμπουνώ τσαντίζομαι
 τσαπίζω τσατάρω τσατίζομαι τσατίζω τσεκάρω τσεκουρώνω τσεπώνω τσευδίζω
 τσιγκλάω τσιγκλώ τσιγκουνεύομαι τσικνίζω τσιλημπουρδάω τσιλημπουρδίζω
 τσιληπουρδίζω τσιληπουρδώ τσιληπουρδῶ τσιλλώ τσιμεντάρω τσιμπάω τσιμπιέμαι
 τσιμπολογάω τσιμπολογώ τσιμπουκώνω τσιμπώ τσινώ τσιρίζω τσιρλίζω τσιρλώ
 τσιτσιρίζω τσιτώνω τσοντάρω τσουβαλιάζω τσουγκρίζω τσουγκρανίζω τσουλώ τσουρλώ
 τσουτσουρώνω τσούζω τυγχάνω τυλίγομαι τυλίγω τυλίσσω τυλιγαδιάζω τυλώνω
 τυπάζω τυποκλοπώ τυποποιώ τυπώνω τυραγνώ τυραννεύω τυραννώ τυρβάζω τυροκομώ
 τυφεκίζω τυφλώνω τυφλώττω τυχαίνω τυχαιογράφημα τυχαιογραφία τυχαιογραφίζω
 τύπτω υαλογραφώ υαλοποιώ υβρίζω υβριδίζω υγιαίνω υγραίνομαι υγραίνω υγροποιώ
 υδατώνω υδρεύομαι υδρεύω υδρογονώνω υδροδοτώ υδρολύω υδροχρωματίζω υιοθετώ
 υλακτώ υλοποιούμαι υλοποιώ υλοτομώ υμνογραφώ υμνολογώ υμνούμαι υμνωδώ υμνώ
 υπάγω υπάρχω υπέρκειμαι υπέχω υπαγορεύω υπαινίσσομαι υπακούω υπαναχωρώ
 υπαντώ υπατεύω υπείκω υπεισέρχομαι υπεκκαίω υπεκμισθώνω υπεκφεύγω υπενδύω
 υπενοικιάζω υπεξάγω υπεξαιρώ υπερέχω υπερίπταμαι υπεραίρομαι υπεραίρω
 υπερακοντίζω υπεραμύνομαι υπερανακτώ υπεραντισταθμίζω υπεραπλουστεύω
 υπερασπίζω υπεραυξάνω υπερβάλλω υπερβαίνω υπερεκκρίνω υπερεκπληρώνω
 υπερεκτιμώ υπερεκχειλίζω υπερεντείνω υπερεπαρκώ υπερευχαριστώ υπερηφανεύομαι
 υπερθερμαίνομαι υπερθερμαίνω υπεριδρώνω υπερισχύω υπερκαλύπτομαι υπερκαλύπτω
 υπερκερώ υπερμαχώ υπερνικώ υπερπηδώ υπερπληρώνω υπερπροστατεύω υπερσιτίζω
 υπερτερώ υπερτιμολογώ υπερτιμώ υπερυψώνω υπερφαλαγγίζω υπερφορτίζω
 υπερφορτώνω υπερφουσκώνομαι υπερφουσκώνω υπερχειλίζω υπερχρεώνομαι υπερχρεώνω
 υπερψηφίζω υπερωριμάζω υπηρετώ υπνοβατώ υπνωτίζομαι υπνωτίζω υπνώνω υπνώττω
 υποβάλλομαι υποβάλλω υποβαθμίζω υποβαστάζω υποβιβάζω υποβλέπω υποβοηθούμενος
 υποβόσκω υπογειώνω υπογράφω υπογραμμίζω υποδένομαι υποδένω υποδέχομαι
 υποδείχνω υποδεικνύω υποδηλώνω υποδιαιρώ υποδουλώνω υποδύομαι υποεκτιμώ
 υποθέτω υποθερμαίνω υποθηκεύω υποκαθίσταμαι υποκαθιστώ υποκαιώ
 υποκινώ υποκλέπτω υποκλίνομαι υποκρίνομαι υποκρούω υποκρύπτομαι υποκρύπτω
 υπολήπτομαι υπολαμβάνω υπολανθάνω υπολείπομαι υπολειτουργώ υπολογίζομαι
 υπομένω υπομειδιώ υπομιμνήσκω υπομισθώνω υπομνηματίζω υπομονεύω υπομοχλεύω
 υπονοώ υπονυστάζω υποπίπτω υποπληθύνομαι υποπτεύομαι υπορράπτω υποσημαίνω
 υποσιτίζω υποσκάβω υποσκάπτω υποσκελίζω υποσκιάζω υποστέλλω υποστασιοποιώ
 υποστρέφω υποστυλώνω υποτάσσομαι υποτάσσω υποτίθεται υποτιμώ υποτιμώμαι
 υποτονίζω υποτονθορύζω υποτρέμω υποτρίζω υποτροπιάζω υπουργεύω υπουργώ υποφέρω
 υποχονδριάζω υποχοντριάζω υποχρεούμαι υποχρεώνομαι υποχρεώνω υποχωρώ
 υποψιάζω υπτιάζω υπόκειμαι υπόσχομαι υστερολογώ υστερώ υφέρπω υφίσταμαι υφαίνω
 υψηλοφρονώ υψώνομαι υψώνω φάσκω φέγγω φέρνομαι φέρνω φέρομαι φέρω φαίνεται
 φαίνω φαγουρίζω φαγώνομαι φαιδρολογώ φαιδρύνω φακελώνω φακιολίζω φακκώ φαλίρω
 φαλιρίζω φαλκιδεύω φαλλίρω φαλλοθρέφω φαλτσάρω φαμπρικάρω φανίζομαι
 φανατίζω φανερώνομαι φανερώνω φαντάζομαι φαντάζω φαντασιοκοπώ φαρδαίνω φαρδύνω
 φαρμακώνομαι φαρμακώνω φασίζω φασκελώνομαι φασκελώνω φασκιώνω φασώνομαι φασώνω
 φαφλατάρω φαφλατίζω φαφουτιάζω φαφουτιαίνω φείδομαι φεγγίζω φεγγαριάζομαι
 φεγγοβολώ φεγγοβολῶ φεγγρίζω φειδωλεύομαι φελιάζω φελώ φενακίζω φερμάρω
 φεσώνω φευγατίζω φεύγω φηκαρώνω φημίζομαι φθάνω φθέγγομαι φθίνω φθείρομαι
 φθείρω φθειαρμίζω φθειρίζω φθειριώ φθηναίνω φθινοπωριάζει φθισιώ φθονώ
 φιδοσέρνομαι φιλάω φιλεύω φιλιέμαι φιλιώνω φιλμάρω φιλοδοξώ φιλοδωρώ φιλοκαλώ
 φιλονικώ φιλοξενούμαι φιλοξενώ φιλοσοφώ φιλοτεχνώ φιλοτιμούμαι φιλοτιμώ
 φιλτράρω φιλώ φιλῶ φιμώνομαι φιμώνω φινίρω φιξάρω φιστικώνω φισφιρίζω
 φκιάνω φκιασιδώνω φλέγομαι φλέγω φλεβίζω φλεβοτομώ φλεγμαίνω φλερτάρω φληναφώ
 φλογίζω φλογοβολώ φλογώνω φλοισβίζω φλοκιάζω φλομιάζω φλομώνω φλυαρώ φοβάμαι
 φοβερίζω φοβούμαι φοδράρω φοδραρίζω φοιτώ φονεύω φοντράρω φοντραρίζω φοριέμαι
 φοροδιαφεύγω φορολογούμαι φορολογώ φορτίζομαι φορτίζω φορτσάρω φορτώνομαι
 φορώ φουλάρω φουμάρω φουμέρνω φουντάρω φουντώνω φουρκίζω φουρνίζω φουρτουνιάζω
 φουσκαλιάζω φουσκώνομαι φουσκώνω φουχτώνω φράζω φράσσω φρίσσω φρίττω
 φραγκεύω φραγκογλωττώ φρακάρω φρεζάρω φρενάρω φρενιάζω φρεσκάρω φριζάρω
 φρικιάζω φρικιώ φριμάζω φριμάσσομαι φροκαλίζω φροκαλώ φρονηματίζω φρονιμεύω
 φρονώ φρονῶ φρουμάζω φρουρούμαι φρουρώ φρυάζω φρυγανίζω φρύγω φτάνω φταίω
 φταρνίζομαι φτεριάζω φτερνίζομαι φτερνοκοπώ φτεροκοπώ φτερουγίζω φτερουγώ
 φτηναίνω φτιάνω φτιάχνομαι φτιάχνω φτιασιδώνομαι φτιασιδώνω φτουρώ φτυαρίζω
 φτωχαίνω φτωχοποιώ φτύνομαι φτύνω φυγαδεύω φυγοδικώ φυγοκεντρίζω φυγομαχώ
 φυλάγομαι φυλάγω φυλάσσομαι φυλάσσω φυλάω φυλακίζομαι φυλακίζω φυλακώνω
 φυλλοβολώ φυλλομαδώ φυλλομετρώ φυλλορροώ φυλλοφορώ φυραίνω φυρώ φυσάω φυσομανώ
 φυσῶ φυτεύω φυτοζοώ φυτοζωώ φυτρώνω φχαριστιέμαι φωλεύω φωλιάζω φωνάζω φωνασκώ
 φωρώμαι φωσφατώνω φωσφορίζω φωσφορυλιώνω φωτάω φωτίζομαι φωτίζω φωταγωγώ
 φωτογραφίζομαι φωτογραφίζω φωτογραφώ φωτοσκιάζω φωτοσυνθέτω φωτοτυπώ φύομαι
 χάνομαι χάνω χάσκω χάφτω χέζομαι χέζω χέω χαίνω χαίρομαι χαίρω χαδεύω χαζεύω
 χαζολογώ χαιρεκακώ χαιρετίζω χαιρετώ χακάρω χαλάω χαλαλίζω χαλαρώνω χαλβαδιάζω
 χαλικοστρώνω χαλικώνω χαλιναγωγώ χαλιναγωγῶ χαλιναρώνω χαλινώνω χαλκεύω
 χαλνώ χαλυβδώνω χαλυβοποιώ χαλυβώνω χαλώ χαλώνω χαμαλικεύω χαμηλώνω χαμογελώ
 χαμοσέρνω χαμπαρίζω χαμπαριάζω χαντακώνω χαντράρω χαπακώνω χαπιάρω χαράζω
 χαρίζομαι χαρίζω χαρακτηρίζομαι χαρακτηρίζω χαρακώνομαι χαρακώνω χαραμίζω
 χαριεντίζομαι χαριτολογώ χαρμανιάζω χαροκοπώ χαροπαλεύω χαροποιώ χαρτζιλικώνω
 χαρτοδένω χαρτοδετούμαι χαρτοδετώ χαρτοκλέβω χαρτοκλέπτω χαρτοπαίζω
 χαρτώνω χαρχαλεύω χασισώνω χασκαρίζω χασκογελώ χασμουριέμαι χασομερώ
 χαυνώνω χαχανίζω χαϊδεύω χαϊδολογώ χειμάζομαι χειμωνιάζει χειρίζομαι χειραγωγώ
 χειροδικώ χειροκροτώ χειρονομώ χειρονομῶ χειροπεδώ χειροτερεύω χειροτεχνώ
 χειροτονώ χειρουργοῦμαι χειρουργώ χειρουργῶ χερακώνω χεριάζω χεροβολιάζω
 χερουκλώνω χερσώνω χηρεύω χιάζω χιλιάζω χιμίζω χιμώ χιονίζει χιονίζω χιονοβολώ
 χλαπακιάζω χλευάζω χλιαίνω χλιμιντρίζω χλιμιντρώ χλοΐζω χλοάζω χλομιάζω
 χλωμιάζω χλωριώνω χλωροφορμίζω χνοάζω χνουδιάζω χολεριάζω χολεριώ χολιάζω
 χολοσκάνω χολοσκάω χολώνω χοντραίνω χοντροδουλεύω χοντρύνω χορδίζω χορεύω
 χορηγῶ χορογραφώ χοροπηδώ χοροστατώ χορταίνω χορταριάζω χουγιάζω χουζουρεύω
 χουφτώνω χουχουλίζω χουχουλιάζω χοχλάζω χοχλακίζω χοχλακιάζω χοχλακώ χρήζω
 χρίω χραίνω χρειάζομαι χρεμετίζω χρεοκοπώ χρεοπιστώνω χρεωκοπώ χρεωστώ
 χρεώνω χρηματίζομαι χρηματίζω χρηματοδοτώ χρηματολογώ χρησιμεύω
 χρησιμοποιώ χρησμοδοτώ χρησμολογώ χρονίζω χρονιάζω χρονογραφώ χρονολογώ
 χρονοτριβώ χρυσίζω χρυσοβάφω χρυσοδένω χρυσοκεντώ χρυσοπλέκω χρυσοπληρώνω
 χρυσοστολίζω χρυσώνω χρωματίζομαι χρωματίζω χρωματογραφώ χρωστάω χρωστώ χτίζω
 χτικιάζω χτυπάω χτυπιέμαι χτυποκαρδίζω χτυπώ χυδαΐζω χυδαιολογώ χυλοποιώ
 χυμώ χωλαίνω χωματίζω χωνεύω χωράω χωρίζομαι χωρίζω χωρατεύω χωριατεύω
 χωροθετώ χωρομετρώ χωροσταθμώ χωρώ χύνομαι χύνω χώνομαι χώνω ψάλλομαι ψάλλω
 ψάχνω ψέγω ψέλνω ψένω ψήνομαι ψήνω ψήχω ψαθώνω ψακώνω ψαλαφώ ψαλιδίζω ψαλιδώνω
 ψαρεύομαι ψαρεύω ψαρώνω ψαχουλεύομαι ψαχουλεύω ψαύω ψεγαδιάζω ψειρίζω ψειριάζω
 ψεκάζω ψελλίζω ψευδίζω ψευδαργυρώνω ψευδοαπασχολούμαι ψευδολογώ ψευδομαρτυρώ
 ψευτίζω ψευταγαπώ ψευτοαπασχολούμαι ψευτοζώ ψευτοπερνώ ψεύδομαι ψηλαρμενίζω
 ψηλαφώ ψηλώνω ψηφάω ψηφίζομαι ψηφίζω ψηφιοποιώ ψηφοθετώ ψηφοθηρώ ψηφοφορώ ψηφώ
 ψιθυρίζεται ψιθυρίζω ψιλοβρέχει ψιλογνέθω ψιλοδουλεύω ψιλοκοσκινίζω
 ψιλοκόβω ψιλολογώ ψιλορωτώ ψιλοσυμπαθώ ψιλοτρώω ψιλοτσιμπώ ψιλούμαι ψιλοῦμαι
 ψιμυθιώνομαι ψιττακίζω ψιχαλίζει ψιχαλίζω ψιψιρίζω ψοφάω ψοφολογώ ψοφώ ψυλλίζω
 ψυλλιάζω ψυχαγωγώ ψυχαγωγῶ ψυχαναγκάζω ψυχαναλύω ψυχανεμίζομαι ψυχογραφώ
 ψυχολογώ ψυχομαχώ ψυχοπιάνομαι ψυχοπλακώνομαι ψυχοπλακώνω ψυχοπονώ ψυχορραγώ
 ψυχραίνω ψυχρηλατώ ψυχώνω ψωμίζομαι ψωμίζω ψωμοζητώ ψωμοζώ ψωμοτρώγω ψωμώνω
 ψωνίζω ψωριάζω ψύχομαι ψύχω ωδίνω ωδινώμαι ωθούμαι ωθώ ωραιοποιούμαι ωραιοποιώ
 ωρύομαι ωτακουστώ ωτοσκοπώ ωφελούμαι ωφελώ ωχραίνω ωχριώ όζω όψομαι ἀδικῶ
 ἀκροῶμαι ἀλέθω ἀμελῶ ἀναπτερυγιάζω ἀναπτερώνω ἀναπτερώνω ἀνασαίνω ἀναταράσσω
 ἀναφτερουγίζω ἀναφτερουγιάζω ἀναφτερώνω ἀναχωρίζω ἀντιμετρῶ ἀράζω ἀφοδεύω
""".split())
